"use strict";(self.webpackChunkgrafana=self.webpackChunkgrafana||[]).push([[9020],{22172(mO,ju,et){et.r(ju),et.d(ju,{DELETE:()=>Wo,DataSet:()=>wg,DataStream:()=>Br,DataView:()=>Pu,Queue:()=>Rt,createNewDataPipeFrom:()=>Wb,isDataSetLike:()=>Ag,isDataViewLike:()=>vO});/**
 * vis-data
 * http://visjs.org/
 *
 * Manage unstructured data using DataSet. Add, update, and remove data, and listen for changes in the data.
 *
 * @version 8.0.3
 * @date    2025-09-10T16:22:00.613Z
 *
 * @copyright (c) 2011-2017 Almende B.V, http://almende.com
 * @copyright (c) 2017-2019 visjs contributors, https://github.com/visjs
 *
 * @license
 * vis.js is dual licensed under both
 *
 *   1. The Apache 2.0 License
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *   and
 *
 *   2. The MIT License
 *      http://opensource.org/licenses/MIT
 *
 * vis.js may be distributed under either license.
 */var Mu=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof et.g<"u"?et.g:typeof self<"u"?self:{};function $(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}var wt={exports:{}},Nu={},Ie,Fu;function K(){if(Fu)return Ie;Fu=1;var e=function(r){return r&&r.Math===Math&&r};return Ie=e(typeof globalThis=="object"&&globalThis)||e(typeof window=="object"&&window)||e(typeof self=="object"&&self)||e(typeof Mu=="object"&&Mu)||e(typeof Ie=="object"&&Ie)||function(){return this}()||Function("return this")(),Ie}var At,Lu;function j(){return Lu||(Lu=1,At=function(e){try{return!!e()}catch{return!0}}),At}var $t,Bu;function Oe(){if(Bu)return $t;Bu=1;var e=j();return $t=!e(function(){var r=function(){}.bind();return typeof r!="function"||r.hasOwnProperty("prototype")}),$t}var Dt,ku;function tt(){if(ku)return Dt;ku=1;var e=Oe(),r=Function.prototype,t=r.apply,n=r.call;return Dt=typeof Reflect=="object"&&Reflect.apply||(e?n.bind(t):function(){return n.apply(t,arguments)}),Dt}var Ct,Ku;function N(){if(Ku)return Ct;Ku=1;var e=Oe(),r=Function.prototype,t=r.call,n=e&&r.bind.bind(t,t);return Ct=e?n:function(i){return function(){return t.apply(i,arguments)}},Ct}var xt,Uu;function Rr(){if(Uu)return xt;Uu=1;var e=N(),r=e({}.toString),t=e("".slice);return xt=function(n){return t(r(n),8,-1)},xt}var jt,Gu;function Wu(){if(Gu)return jt;Gu=1;var e=Rr(),r=N();return jt=function(t){if(e(t)==="Function")return r(t)},jt}var Mt,Vu;function z(){if(Vu)return Mt;Vu=1;var e=typeof document=="object"&&document.all;return Mt=typeof e>"u"&&e!==void 0?function(r){return typeof r=="function"||r===e}:function(r){return typeof r=="function"},Mt}var Nt={},Ft,Hu;function U(){if(Hu)return Ft;Hu=1;var e=j();return Ft=!e(function(){return Object.defineProperty({},1,{get:function(){return 7}})[1]!==7}),Ft}var Lt,zu;function nr(){if(zu)return Lt;zu=1;var e=Oe(),r=Function.prototype.call;return Lt=e?r.bind(r):function(){return r.apply(r,arguments)},Lt}var Bt={},Yu;function kt(){if(Yu)return Bt;Yu=1;var e={}.propertyIsEnumerable,r=Object.getOwnPropertyDescriptor,t=r&&!e.call({1:2},1);return Bt.f=t?function(i){var a=r(this,i);return!!a&&a.enumerable}:e,Bt}var Kt,Xu;function Re(){return Xu||(Xu=1,Kt=function(e,r){return{enumerable:!(e&1),configurable:!(e&2),writable:!(e&4),value:r}}),Kt}var Ut,Ju;function nt(){if(Ju)return Ut;Ju=1;var e=N(),r=j(),t=Rr(),n=Object,i=e("".split);return Ut=r(function(){return!n("z").propertyIsEnumerable(0)})?function(a){return t(a)==="String"?i(a,""):n(a)}:n,Ut}var Gt,Zu;function Te(){return Zu||(Zu=1,Gt=function(e){return e==null}),Gt}var Wt,Qu;function kr(){if(Qu)return Wt;Qu=1;var e=Te(),r=TypeError;return Wt=function(t){if(e(t))throw new r("Can't call method on "+t);return t},Wt}var Vt,rc;function mr(){if(rc)return Vt;rc=1;var e=nt(),r=kr();return Vt=function(t){return e(r(t))},Vt}var Ht,ec;function Q(){if(ec)return Ht;ec=1;var e=z();return Ht=function(r){return typeof r=="object"?r!==null:e(r)},Ht}var zt,tc;function V(){return tc||(tc=1,zt={}),zt}var Yt,nc;function or(){if(nc)return Yt;nc=1;var e=V(),r=K(),t=z(),n=function(i){return t(i)?i:void 0};return Yt=function(i,a){return arguments.length<2?n(e[i])||n(r[i]):e[i]&&e[i][a]||r[i]&&r[i][a]},Yt}var Xt,ic;function H(){if(ic)return Xt;ic=1;var e=N();return Xt=e({}.isPrototypeOf),Xt}var Jt,ac;function ue(){if(ac)return Jt;ac=1;var e=K(),r=e.navigator,t=r&&r.userAgent;return Jt=t?String(t):"",Jt}var Zt,oc;function Pe(){if(oc)return Zt;oc=1;var e=K(),r=ue(),t=e.process,n=e.Deno,i=t&&t.versions||n&&n.version,a=i&&i.v8,o,s;return a&&(o=a.split("."),s=o[0]>0&&o[0]<4?1:+(o[0]+o[1])),!s&&r&&(o=r.match(/Edge\/(\d+)/),(!o||o[1]>=74)&&(o=r.match(/Chrome\/(\d+)/),o&&(s=+o[1]))),Zt=s,Zt}var Qt,sc;function ce(){if(sc)return Qt;sc=1;var e=Pe(),r=j(),t=K(),n=t.String;return Qt=!!Object.getOwnPropertySymbols&&!r(function(){var i=Symbol("symbol detection");return!n(i)||!(Object(i)instanceof Symbol)||!Symbol.sham&&e&&e<41}),Qt}var rn,uc;function cc(){if(uc)return rn;uc=1;var e=ce();return rn=e&&!Symbol.sham&&typeof Symbol.iterator=="symbol",rn}var en,fc;function we(){if(fc)return en;fc=1;var e=or(),r=z(),t=H(),n=cc(),i=Object;return en=n?function(a){return typeof a=="symbol"}:function(a){var o=e("Symbol");return r(o)&&t(o.prototype,i(a))},en}var tn,vc;function fe(){if(vc)return tn;vc=1;var e=String;return tn=function(r){try{return e(r)}catch{return"Object"}},tn}var nn,lc;function gr(){if(lc)return nn;lc=1;var e=z(),r=fe(),t=TypeError;return nn=function(n){if(e(n))return n;throw new t(r(n)+" is not a function")},nn}var an,hc;function on(){if(hc)return an;hc=1;var e=gr(),r=Te();return an=function(t,n){var i=t[n];return r(i)?void 0:e(i)},an}var sn,dc;function Bg(){if(dc)return sn;dc=1;var e=nr(),r=z(),t=Q(),n=TypeError;return sn=function(i,a){var o,s;if(a==="string"&&r(o=i.toString)&&!t(s=e(o,i))||r(o=i.valueOf)&&!t(s=e(o,i))||a!=="string"&&r(o=i.toString)&&!t(s=e(o,i)))return s;throw new n("Can't convert object to primitive value")},sn}var un={exports:{}},cn,pc;function ve(){return pc||(pc=1,cn=!0),cn}var fn,yc;function kg(){if(yc)return fn;yc=1;var e=K(),r=Object.defineProperty;return fn=function(t,n){try{r(e,t,{value:n,configurable:!0,writable:!0})}catch{e[t]=n}return n},fn}var mc;function vn(){if(mc)return un.exports;mc=1;var e=ve(),r=K(),t=kg(),n="__core-js_shared__",i=un.exports=r[n]||t(n,{});return(i.versions||(i.versions=[])).push({version:"3.44.0",mode:e?"pure":"global",copyright:"\xA9 2014-2025 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.44.0/LICENSE",source:"https://github.com/zloirock/core-js"}),un.exports}var ln,gc;function le(){if(gc)return ln;gc=1;var e=vn();return ln=function(r,t){return e[r]||(e[r]=t||{})},ln}var hn,_c;function ur(){if(_c)return hn;_c=1;var e=kr(),r=Object;return hn=function(t){return r(e(t))},hn}var dn,bc;function Y(){if(bc)return dn;bc=1;var e=N(),r=ur(),t=e({}.hasOwnProperty);return dn=Object.hasOwn||function(i,a){return t(r(i),a)},dn}var pn,Sc;function it(){if(Sc)return pn;Sc=1;var e=N(),r=0,t=Math.random(),n=e(1.1.toString);return pn=function(i){return"Symbol("+(i===void 0?"":i)+")_"+n(++r+t,36)},pn}var yn,Ec;function X(){if(Ec)return yn;Ec=1;var e=K(),r=le(),t=Y(),n=it(),i=ce(),a=cc(),o=e.Symbol,s=r("wks"),u=a?o.for||o:o&&o.withoutSetter||n;return yn=function(c){return t(s,c)||(s[c]=i&&t(o,c)?o[c]:u("Symbol."+c)),s[c]},yn}var mn,qc;function Ic(){if(qc)return mn;qc=1;var e=nr(),r=Q(),t=we(),n=on(),i=Bg(),a=X(),o=TypeError,s=a("toPrimitive");return mn=function(u,c){if(!r(u)||t(u))return u;var f=n(u,s),v;if(f){if(c===void 0&&(c="default"),v=e(f,u,c),!r(v)||t(v))return v;throw new o("Can't convert object to primitive value")}return c===void 0&&(c="number"),i(u,c)},mn}var gn,Oc;function _n(){if(Oc)return gn;Oc=1;var e=Ic(),r=we();return gn=function(t){var n=e(t,"string");return r(n)?n:n+""},gn}var bn,Rc;function Tc(){if(Rc)return bn;Rc=1;var e=K(),r=Q(),t=e.document,n=r(t)&&r(t.createElement);return bn=function(i){return n?t.createElement(i):{}},bn}var Sn,Pc;function wc(){if(Pc)return Sn;Pc=1;var e=U(),r=j(),t=Tc();return Sn=!e&&!r(function(){return Object.defineProperty(t("div"),"a",{get:function(){return 7}}).a!==7}),Sn}var Ac;function at(){if(Ac)return Nt;Ac=1;var e=U(),r=nr(),t=kt(),n=Re(),i=mr(),a=_n(),o=Y(),s=wc(),u=Object.getOwnPropertyDescriptor;return Nt.f=e?u:function(f,v){if(f=i(f),v=a(v),s)try{return u(f,v)}catch{}if(o(f,v))return n(!r(t.f,f,v),f[v])},Nt}var En,$c;function Kg(){if($c)return En;$c=1;var e=j(),r=z(),t=/#|\.prototype\./,n=function(u,c){var f=a[i(u)];return f===s?!0:f===o?!1:r(c)?e(c):!!c},i=n.normalize=function(u){return String(u).replace(t,".").toLowerCase()},a=n.data={},o=n.NATIVE="N",s=n.POLYFILL="P";return En=n,En}var qn,Dc;function Ae(){if(Dc)return qn;Dc=1;var e=Wu(),r=gr(),t=Oe(),n=e(e.bind);return qn=function(i,a){return r(i),a===void 0?i:t?n(i,a):function(){return i.apply(a,arguments)}},qn}var In={},On,Cc;function xc(){if(Cc)return On;Cc=1;var e=U(),r=j();return On=e&&r(function(){return Object.defineProperty(function(){},"prototype",{value:42,writable:!1}).prototype!==42}),On}var Rn,jc;function Tr(){if(jc)return Rn;jc=1;var e=Q(),r=String,t=TypeError;return Rn=function(n){if(e(n))return n;throw new t(r(n)+" is not an object")},Rn}var Mc;function cr(){if(Mc)return In;Mc=1;var e=U(),r=wc(),t=xc(),n=Tr(),i=_n(),a=TypeError,o=Object.defineProperty,s=Object.getOwnPropertyDescriptor,u="enumerable",c="configurable",f="writable";return In.f=e?t?function(h,l,d){if(n(h),l=i(l),n(d),typeof h=="function"&&l==="prototype"&&"value"in d&&f in d&&!d[f]){var p=s(h,l);p&&p[f]&&(h[l]=d.value,d={configurable:c in d?d[c]:p[c],enumerable:u in d?d[u]:p[u],writable:!1})}return o(h,l,d)}:o:function(h,l,d){if(n(h),l=i(l),n(d),r)try{return o(h,l,d)}catch{}if("get"in d||"set"in d)throw new a("Accessors not supported");return"value"in d&&(h[l]=d.value),h},In}var Tn,Nc;function he(){if(Nc)return Tn;Nc=1;var e=U(),r=cr(),t=Re();return Tn=e?function(n,i,a){return r.f(n,i,t(1,a))}:function(n,i,a){return n[i]=a,n},Tn}var Pn,Fc;function A(){if(Fc)return Pn;Fc=1;var e=K(),r=tt(),t=Wu(),n=z(),i=at().f,a=Kg(),o=V(),s=Ae(),u=he(),c=Y(),f=function(v){var h=function(l,d,p){if(this instanceof h){switch(arguments.length){case 0:return new v;case 1:return new v(l);case 2:return new v(l,d)}return new v(l,d,p)}return r(v,this,arguments)};return h.prototype=v.prototype,h};return Pn=function(v,h){var l=v.target,d=v.global,p=v.stat,S=v.proto,g=d?e:p?e[l]:e[l]&&e[l].prototype,m=d?o:o[l]||u(o,l,{})[l],T=m.prototype,_,E,I,O,y,b,q,R,P;for(O in h)_=a(d?O:l+(p?".":"#")+O,v.forced),E=!_&&g&&c(g,O),b=m[O],E&&(v.dontCallGetSet?(P=i(g,O),q=P&&P.value):q=g[O]),y=E&&q?q:h[O],!(!_&&!S&&typeof b==typeof y)&&(v.bind&&E?R=s(y,e):v.wrap&&E?R=f(y):S&&n(y)?R=t(y):R=y,(v.sham||y&&y.sham||b&&b.sham)&&u(R,"sham",!0),u(m,O,R),S&&(I=l+"Prototype",c(o,I)||u(o,I,{}),u(o[I],O,y),v.real&&T&&(_||!T[O])&&u(T,O,y)))},Pn}var Lc;function Ug(){if(Lc)return Nu;Lc=1;var e=A(),r=U(),t=cr().f;return e({target:"Object",stat:!0,forced:Object.defineProperty!==t,sham:!r},{defineProperty:t}),Nu}var Bc;function Gg(){if(Bc)return wt.exports;Bc=1,Ug();var e=V(),r=e.Object,t=wt.exports=function(i,a,o){return r.defineProperty(i,a,o)};return r.defineProperty.sham&&(t.sham=!0),wt.exports}var wn,kc;function Kc(){if(kc)return wn;kc=1;var e=Gg();return wn=e,wn}var An,Uc;function Wg(){if(Uc)return An;Uc=1;var e=Kc();return An=e,An}var $n,Gc;function Vg(){if(Gc)return $n;Gc=1;var e=Wg();return $n=e,$n}var Dn,Wc;function Hg(){return Wc||(Wc=1,Dn=Vg()),Dn}var zg=Hg(),Yg=$(zg),Vc={},Cn,Hc;function Cr(){if(Hc)return Cn;Hc=1;var e=Rr();return Cn=Array.isArray||function(t){return e(t)==="Array"},Cn}var xn,zc;function Xg(){if(zc)return xn;zc=1;var e=Math.ceil,r=Math.floor;return xn=Math.trunc||function(n){var i=+n;return(i>0?r:e)(i)},xn}var jn,Yc;function de(){if(Yc)return jn;Yc=1;var e=Xg();return jn=function(r){var t=+r;return t!==t||t===0?0:e(t)},jn}var Mn,Xc;function Jc(){if(Xc)return Mn;Xc=1;var e=de(),r=Math.min;return Mn=function(t){var n=e(t);return n>0?r(n,9007199254740991):0},Mn}var Nn,Zc;function _r(){if(Zc)return Nn;Zc=1;var e=Jc();return Nn=function(r){return e(r.length)},Nn}var Fn,Qc;function Ln(){if(Qc)return Fn;Qc=1;var e=TypeError,r=9007199254740991;return Fn=function(t){if(t>r)throw e("Maximum allowed index exceeded");return t},Fn}var Bn,rf;function ot(){if(rf)return Bn;rf=1;var e=U(),r=cr(),t=Re();return Bn=function(n,i,a){e?r.f(n,i,t(0,a)):n[i]=a},Bn}var kn,ef;function Kn(){if(ef)return kn;ef=1;var e=X(),r=e("toStringTag"),t={};return t[r]="z",kn=String(t)==="[object z]",kn}var Un,tf;function xr(){if(tf)return Un;tf=1;var e=Kn(),r=z(),t=Rr(),n=X(),i=n("toStringTag"),a=Object,o=t(function(){return arguments}())==="Arguments",s=function(u,c){try{return u[c]}catch{}};return Un=e?t:function(u){var c,f,v;return u===void 0?"Undefined":u===null?"Null":typeof(f=s(c=a(u),i))=="string"?f:o?t(c):(v=t(c))==="Object"&&r(c.callee)?"Arguments":v},Un}var Gn,nf;function Jg(){if(nf)return Gn;nf=1;var e=N(),r=z(),t=vn(),n=e(Function.toString);return r(t.inspectSource)||(t.inspectSource=function(i){return n(i)}),Gn=t.inspectSource,Gn}var Wn,af;function of(){if(af)return Wn;af=1;var e=N(),r=j(),t=z(),n=xr(),i=or(),a=Jg(),o=function(){},s=i("Reflect","construct"),u=/^\s*(?:class|function)\b/,c=e(u.exec),f=!u.test(o),v=function(d){if(!t(d))return!1;try{return s(o,[],d),!0}catch{return!1}},h=function(d){if(!t(d))return!1;switch(n(d)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return f||!!c(u,a(d))}catch{return!0}};return h.sham=!0,Wn=!s||r(function(){var l;return v(v.call)||!v(Object)||!v(function(){l=!0})||l})?h:v,Wn}var Vn,sf;function Zg(){if(sf)return Vn;sf=1;var e=Cr(),r=of(),t=Q(),n=X(),i=n("species"),a=Array;return Vn=function(o){var s;return e(o)&&(s=o.constructor,r(s)&&(s===a||e(s.prototype))?s=void 0:t(s)&&(s=s[i],s===null&&(s=void 0))),s===void 0?a:s},Vn}var Hn,uf;function st(){if(uf)return Hn;uf=1;var e=Zg();return Hn=function(r,t){return new(e(r))(t===0?0:t)},Hn}var zn,cf;function $e(){if(cf)return zn;cf=1;var e=j(),r=X(),t=Pe(),n=r("species");return zn=function(i){return t>=51||!e(function(){var a=[],o=a.constructor={};return o[n]=function(){return{foo:1}},a[i](Boolean).foo!==1})},zn}var ff;function vf(){if(ff)return Vc;ff=1;var e=A(),r=j(),t=Cr(),n=Q(),i=ur(),a=_r(),o=Ln(),s=ot(),u=st(),c=$e(),f=X(),v=Pe(),h=f("isConcatSpreadable"),l=v>=51||!r(function(){var S=[];return S[h]=!1,S.concat()[0]!==S}),d=function(S){if(!n(S))return!1;var g=S[h];return g!==void 0?!!g:t(S)},p=!l||!c("concat");return e({target:"Array",proto:!0,arity:1,forced:p},{concat:function(g){var m=i(this),T=u(m,0),_=0,E,I,O,y,b;for(E=-1,O=arguments.length;E<O;E++)if(b=E===-1?m:arguments[E],d(b))for(y=a(b),o(_+y),I=0;I<y;I++,_++)I in b&&s(T,_,b[I]);else o(_+1),s(T,_++,b);return T.length=_,T}}),Vc}var lf={},hf={},Yn,df;function jr(){if(df)return Yn;df=1;var e=xr(),r=String;return Yn=function(t){if(e(t)==="Symbol")throw new TypeError("Cannot convert a Symbol value to a string");return r(t)},Yn}var Xn={},Jn,pf;function Zn(){if(pf)return Jn;pf=1;var e=de(),r=Math.max,t=Math.min;return Jn=function(n,i){var a=e(n);return a<0?r(a+i,0):t(a,i)},Jn}var Qn,yf;function Qg(){if(yf)return Qn;yf=1;var e=mr(),r=Zn(),t=_r(),n=function(i){return function(a,o,s){var u=e(a),c=t(u);if(c===0)return!i&&-1;var f=r(s,c),v;if(i&&o!==o){for(;c>f;)if(v=u[f++],v!==v)return!0}else for(;c>f;f++)if((i||f in u)&&u[f]===o)return i||f||0;return!i&&-1}};return Qn={includes:n(!0),indexOf:n(!1)},Qn}var ri,mf;function De(){return mf||(mf=1,ri={}),ri}var ei,gf;function _f(){if(gf)return ei;gf=1;var e=N(),r=Y(),t=mr(),n=Qg().indexOf,i=De(),a=e([].push);return ei=function(o,s){var u=t(o),c=0,f=[],v;for(v in u)!r(i,v)&&r(u,v)&&a(f,v);for(;s.length>c;)r(u,v=s[c++])&&(~n(f,v)||a(f,v));return f},ei}var ti,bf;function ni(){return bf||(bf=1,ti=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"]),ti}var ii,Sf;function ut(){if(Sf)return ii;Sf=1;var e=_f(),r=ni();return ii=Object.keys||function(n){return e(n,r)},ii}var Ef;function ai(){if(Ef)return Xn;Ef=1;var e=U(),r=xc(),t=cr(),n=Tr(),i=mr(),a=ut();return Xn.f=e&&!r?Object.defineProperties:function(s,u){n(s);for(var c=i(u),f=a(u),v=f.length,h=0,l;v>h;)t.f(s,l=f[h++],c[l]);return s},Xn}var oi,qf;function r_(){if(qf)return oi;qf=1;var e=or();return oi=e("document","documentElement"),oi}var si,If;function ct(){if(If)return si;If=1;var e=le(),r=it(),t=e("keys");return si=function(n){return t[n]||(t[n]=r(n))},si}var ui,Of;function Ce(){if(Of)return ui;Of=1;var e=Tr(),r=ai(),t=ni(),n=De(),i=r_(),a=Tc(),o=ct(),s=">",u="<",c="prototype",f="script",v=o("IE_PROTO"),h=function(){},l=function(m){return u+f+s+m+u+"/"+f+s},d=function(m){m.write(l("")),m.close();var T=m.parentWindow.Object;return m=null,T},p=function(){var m=a("iframe"),T="java"+f+":",_;return m.style.display="none",i.appendChild(m),m.src=String(T),_=m.contentWindow.document,_.open(),_.write(l("document.F=Object")),_.close(),_.F},S,g=function(){try{S=new ActiveXObject("htmlfile")}catch{}g=typeof document<"u"?document.domain&&S?d(S):p():d(S);for(var m=t.length;m--;)delete g[c][t[m]];return g()};return n[v]=!0,ui=Object.create||function(T,_){var E;return T!==null?(h[c]=e(T),E=new h,h[c]=null,E[v]=T):E=g(),_===void 0?E:r.f(E,_)},ui}var ci={},Rf;function ft(){if(Rf)return ci;Rf=1;var e=_f(),r=ni(),t=r.concat("length","prototype");return ci.f=Object.getOwnPropertyNames||function(i){return e(i,t)},ci}var fi={},vi,Tf;function pe(){if(Tf)return vi;Tf=1;var e=N();return vi=e([].slice),vi}var Pf;function wf(){if(Pf)return fi;Pf=1;var e=Rr(),r=mr(),t=ft().f,n=pe(),i=typeof window=="object"&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],a=function(o){try{return t(o)}catch{return n(i)}};return fi.f=function(s){return i&&e(s)==="Window"?a(s):t(r(s))},fi}var li={},Af;function vt(){return Af||(Af=1,li.f=Object.getOwnPropertySymbols),li}var hi,$f;function xe(){if($f)return hi;$f=1;var e=he();return hi=function(r,t,n,i){return i&&i.enumerable?r[t]=n:e(r,t,n),r},hi}var di,Df;function pi(){if(Df)return di;Df=1;var e=cr();return di=function(r,t,n){return e.f(r,t,n)},di}var yi={},Cf;function lt(){if(Cf)return yi;Cf=1;var e=X();return yi.f=e,yi}var mi,xf;function B(){if(xf)return mi;xf=1;var e=V(),r=Y(),t=lt(),n=cr().f;return mi=function(i){var a=e.Symbol||(e.Symbol={});r(a,i)||n(a,i,{value:t.f(i)})},mi}var gi,jf;function Mf(){if(jf)return gi;jf=1;var e=nr(),r=or(),t=X(),n=xe();return gi=function(){var i=r("Symbol"),a=i&&i.prototype,o=a&&a.valueOf,s=t("toPrimitive");a&&!a[s]&&n(a,s,function(u){return e(o,this)},{arity:1})},gi}var _i,Nf;function e_(){if(Nf)return _i;Nf=1;var e=Kn(),r=xr();return _i=e?{}.toString:function(){return"[object "+r(this)+"]"},_i}var bi,Ff;function Kr(){if(Ff)return bi;Ff=1;var e=Kn(),r=cr().f,t=he(),n=Y(),i=e_(),a=X(),o=a("toStringTag");return bi=function(s,u,c,f){var v=c?s:s&&s.prototype;v&&(n(v,o)||r(v,o,{configurable:!0,value:u}),f&&!e&&t(v,"toString",i))},bi}var Si,Lf;function t_(){if(Lf)return Si;Lf=1;var e=K(),r=z(),t=e.WeakMap;return Si=r(t)&&/native code/.test(String(t)),Si}var Ei,Bf;function je(){if(Bf)return Ei;Bf=1;var e=t_(),r=K(),t=Q(),n=he(),i=Y(),a=vn(),o=ct(),s=De(),u="Object already initialized",c=r.TypeError,f=r.WeakMap,v,h,l,d=function(m){return l(m)?h(m):v(m,{})},p=function(m){return function(T){var _;if(!t(T)||(_=h(T)).type!==m)throw new c("Incompatible receiver, "+m+" required");return _}};if(e||a.state){var S=a.state||(a.state=new f);S.get=S.get,S.has=S.has,S.set=S.set,v=function(m,T){if(S.has(m))throw new c(u);return T.facade=m,S.set(m,T),T},h=function(m){return S.get(m)||{}},l=function(m){return S.has(m)}}else{var g=o("state");s[g]=!0,v=function(m,T){if(i(m,g))throw new c(u);return T.facade=m,n(m,g,T),T},h=function(m){return i(m,g)?m[g]:{}},l=function(m){return i(m,g)}}return Ei={set:v,get:h,has:l,enforce:d,getterFor:p},Ei}var qi,kf;function ye(){if(kf)return qi;kf=1;var e=Ae(),r=N(),t=nt(),n=ur(),i=_r(),a=st(),o=r([].push),s=function(u){var c=u===1,f=u===2,v=u===3,h=u===4,l=u===6,d=u===7,p=u===5||l;return function(S,g,m,T){for(var _=n(S),E=t(_),I=i(E),O=e(g,m),y=0,b=T||a,q=c?b(S,I):f||d?b(S,0):void 0,R,P;I>y;y++)if((p||y in E)&&(R=E[y],P=O(R,y,_),u))if(c)q[y]=P;else if(P)switch(u){case 3:return!0;case 5:return R;case 6:return y;case 2:o(q,R)}else switch(u){case 4:return!1;case 7:o(q,R)}return l?-1:v||h?h:q}};return qi={forEach:s(0),map:s(1),filter:s(2),some:s(3),every:s(4),find:s(5),findIndex:s(6),filterReject:s(7)},qi}var Kf;function n_(){if(Kf)return hf;Kf=1;var e=A(),r=K(),t=nr(),n=N(),i=ve(),a=U(),o=ce(),s=j(),u=Y(),c=H(),f=Tr(),v=mr(),h=_n(),l=jr(),d=Re(),p=Ce(),S=ut(),g=ft(),m=wf(),T=vt(),_=at(),E=cr(),I=ai(),O=kt(),y=xe(),b=pi(),q=le(),R=ct(),P=De(),w=it(),M=X(),W=lt(),ie=B(),tr=Mf(),Er=Kr(),qr=je(),ae=ye().forEach,k=R("hidden"),Ir="Symbol",Or="prototype",yr=qr.set,Ze=qr.getterFor(Ir),hr=Object[Or],oe=r.Symbol,Qe=oe&&oe[Or],lO=r.RangeError,hO=r.TypeError,wu=r.QObject,$g=_.f,se=E.f,Dg=m.f,dO=O.f,Cg=n([].push),Dr=q("symbols"),rt=q("op-symbols"),pO=q("wks"),Au=!wu||!wu[Or]||!wu[Or].findChild,xg=function(F,D,C){var x=$g(hr,D);x&&delete hr[D],se(F,D,C),x&&F!==hr&&se(hr,D,x)},$u=a&&s(function(){return p(se({},"a",{get:function(){return se(this,"a",{value:7}).a}})).a!==7})?xg:se,Du=function(F,D){var C=Dr[F]=p(Qe);return yr(C,{type:Ir,tag:F,description:D}),a||(C.description=D),C},Pt=function(D,C,x){D===hr&&Pt(rt,C,x),f(D);var L=h(C);return f(x),u(Dr,L)?(x.enumerable?(u(D,k)&&D[k][L]&&(D[k][L]=!1),x=p(x,{enumerable:d(0,!1)})):(u(D,k)||se(D,k,d(1,p(null))),D[k][L]=!0),$u(D,L,x)):se(D,L,x)},Cu=function(D,C){f(D);var x=v(C),L=S(x).concat(Ng(x));return ae(L,function(ar){(!a||t(xu,x,ar))&&Pt(D,ar,x[ar])}),D},yO=function(D,C){return C===void 0?p(D):Cu(p(D),C)},xu=function(D){var C=h(D),x=t(dO,this,C);return this===hr&&u(Dr,C)&&!u(rt,C)?!1:x||!u(this,C)||!u(Dr,C)||u(this,k)&&this[k][C]?x:!0},jg=function(D,C){var x=v(D),L=h(C);if(!(x===hr&&u(Dr,L)&&!u(rt,L))){var ar=$g(x,L);return ar&&u(Dr,L)&&!(u(x,k)&&x[k][L])&&(ar.enumerable=!0),ar}},Mg=function(D){var C=Dg(v(D)),x=[];return ae(C,function(L){!u(Dr,L)&&!u(P,L)&&Cg(x,L)}),x},Ng=function(F){var D=F===hr,C=Dg(D?rt:v(F)),x=[];return ae(C,function(L){u(Dr,L)&&(!D||u(hr,L))&&Cg(x,Dr[L])}),x};return o||(oe=function(){if(c(Qe,this))throw new hO("Symbol is not a constructor");var D=!arguments.length||arguments[0]===void 0?void 0:l(arguments[0]),C=w(D),x=function(L){var ar=this===void 0?r:this;ar===hr&&t(x,rt,L),u(ar,k)&&u(ar[k],C)&&(ar[k][C]=!1);var Fg=d(1,L);try{$u(ar,C,Fg)}catch(Lg){if(!(Lg instanceof lO))throw Lg;xg(ar,C,Fg)}};return a&&Au&&$u(hr,C,{configurable:!0,set:x}),Du(C,D)},Qe=oe[Or],y(Qe,"toString",function(){return Ze(this).tag}),y(oe,"withoutSetter",function(F){return Du(w(F),F)}),O.f=xu,E.f=Pt,I.f=Cu,_.f=jg,g.f=m.f=Mg,T.f=Ng,W.f=function(F){return Du(M(F),F)},a&&(b(Qe,"description",{configurable:!0,get:function(){return Ze(this).description}}),i||y(hr,"propertyIsEnumerable",xu,{unsafe:!0}))),e({global:!0,constructor:!0,wrap:!0,forced:!o,sham:!o},{Symbol:oe}),ae(S(pO),function(F){ie(F)}),e({target:Ir,stat:!0,forced:!o},{useSetter:function(){Au=!0},useSimple:function(){Au=!1}}),e({target:"Object",stat:!0,forced:!o,sham:!a},{create:yO,defineProperty:Pt,defineProperties:Cu,getOwnPropertyDescriptor:jg}),e({target:"Object",stat:!0,forced:!o},{getOwnPropertyNames:Mg}),tr(),Er(oe,Ir),P[k]=!0,hf}var Uf={},Ii,Gf;function Wf(){if(Gf)return Ii;Gf=1;var e=ce();return Ii=e&&!!Symbol.for&&!!Symbol.keyFor,Ii}var Vf;function i_(){if(Vf)return Uf;Vf=1;var e=A(),r=or(),t=Y(),n=jr(),i=le(),a=Wf(),o=i("string-to-symbol-registry"),s=i("symbol-to-string-registry");return e({target:"Symbol",stat:!0,forced:!a},{for:function(u){var c=n(u);if(t(o,c))return o[c];var f=r("Symbol")(c);return o[c]=f,s[f]=c,f}}),Uf}var Hf={},zf;function a_(){if(zf)return Hf;zf=1;var e=A(),r=Y(),t=we(),n=fe(),i=le(),a=Wf(),o=i("symbol-to-string-registry");return e({target:"Symbol",stat:!0,forced:!a},{keyFor:function(u){if(!t(u))throw new TypeError(n(u)+" is not a symbol");if(r(o,u))return o[u]}}),Hf}var Yf={},Oi,Xf;function o_(){if(Xf)return Oi;Xf=1;var e=N(),r=Cr(),t=z(),n=Rr(),i=jr(),a=e([].push);return Oi=function(o){if(t(o))return o;if(r(o)){for(var s=o.length,u=[],c=0;c<s;c++){var f=o[c];typeof f=="string"?a(u,f):(typeof f=="number"||n(f)==="Number"||n(f)==="String")&&a(u,i(f))}var v=u.length,h=!0;return function(l,d){if(h)return h=!1,d;if(r(this))return d;for(var p=0;p<v;p++)if(u[p]===l)return d}}},Oi}var Jf;function Zf(){if(Jf)return Yf;Jf=1;var e=A(),r=or(),t=tt(),n=nr(),i=N(),a=j(),o=z(),s=we(),u=pe(),c=o_(),f=ce(),v=String,h=r("JSON","stringify"),l=i(/./.exec),d=i("".charAt),p=i("".charCodeAt),S=i("".replace),g=i(1.1.toString),m=/[\uD800-\uDFFF]/g,T=/^[\uD800-\uDBFF]$/,_=/^[\uDC00-\uDFFF]$/,E=!f||a(function(){var b=r("Symbol")("stringify detection");return h([b])!=="[null]"||h({a:b})!=="{}"||h(Object(b))!=="{}"}),I=a(function(){return h("\uDF06\uD834")!=='"\\udf06\\ud834"'||h("\uDEAD")!=='"\\udead"'}),O=function(b,q){var R=u(arguments),P=c(q);if(!(!o(P)&&(b===void 0||s(b))))return R[1]=function(w,M){if(o(P)&&(M=n(P,this,v(w),M)),!s(M))return M},t(h,null,R)},y=function(b,q,R){var P=d(R,q-1),w=d(R,q+1);return l(T,b)&&!l(_,w)||l(_,b)&&!l(T,P)?"\\u"+g(p(b,0),16):b};return h&&e({target:"JSON",stat:!0,arity:3,forced:E||I},{stringify:function(q,R,P){var w=u(arguments),M=t(E?O:h,null,w);return I&&typeof M=="string"?S(M,m,y):M}}),Yf}var Qf={},rv;function s_(){if(rv)return Qf;rv=1;var e=A(),r=ce(),t=j(),n=vt(),i=ur(),a=!r||t(function(){n.f(1)});return e({target:"Object",stat:!0,forced:a},{getOwnPropertySymbols:function(s){var u=n.f;return u?u(i(s)):[]}}),Qf}var ev;function tv(){return ev||(ev=1,n_(),i_(),a_(),Zf(),s_()),lf}var nv={},iv;function av(){if(iv)return nv;iv=1;var e=B();return e("asyncDispose"),nv}var ov={},sv;function u_(){if(sv)return ov;sv=1;var e=B();return e("asyncIterator"),ov}var uv={},cv;function fv(){if(cv)return uv;cv=1;var e=B();return e("dispose"),uv}var vv={},lv;function c_(){if(lv)return vv;lv=1;var e=B();return e("hasInstance"),vv}var hv={},dv;function f_(){if(dv)return hv;dv=1;var e=B();return e("isConcatSpreadable"),hv}var pv={},yv;function mv(){if(yv)return pv;yv=1;var e=B();return e("iterator"),pv}var gv={},_v;function v_(){if(_v)return gv;_v=1;var e=B();return e("match"),gv}var bv={},Sv;function l_(){if(Sv)return bv;Sv=1;var e=B();return e("matchAll"),bv}var Ev={},qv;function h_(){if(qv)return Ev;qv=1;var e=B();return e("replace"),Ev}var Iv={},Ov;function d_(){if(Ov)return Iv;Ov=1;var e=B();return e("search"),Iv}var Rv={},Tv;function p_(){if(Tv)return Rv;Tv=1;var e=B();return e("species"),Rv}var Pv={},wv;function y_(){if(wv)return Pv;wv=1;var e=B();return e("split"),Pv}var Av={},$v;function Dv(){if($v)return Av;$v=1;var e=B(),r=Mf();return e("toPrimitive"),r(),Av}var Cv={},xv;function m_(){if(xv)return Cv;xv=1;var e=or(),r=B(),t=Kr();return r("toStringTag"),t(e("Symbol"),"Symbol"),Cv}var jv={},Mv;function g_(){if(Mv)return jv;Mv=1;var e=B();return e("unscopables"),jv}var Nv={},Fv;function __(){if(Fv)return Nv;Fv=1;var e=K(),r=Kr();return r(e.JSON,"JSON",!0),Nv}var Ri,Lv;function b_(){if(Lv)return Ri;Lv=1,vf(),tv(),av(),u_(),fv(),c_(),f_(),mv(),v_(),l_(),h_(),d_(),p_(),y_(),Dv(),m_(),g_(),__();var e=V();return Ri=e.Symbol,Ri}var Bv={},Ti,kv;function Kv(){return kv||(kv=1,Ti=function(){}),Ti}var Pi,Uv;function me(){return Uv||(Uv=1,Pi={}),Pi}var wi,Gv;function S_(){if(Gv)return wi;Gv=1;var e=U(),r=Y(),t=Function.prototype,n=e&&Object.getOwnPropertyDescriptor,i=r(t,"name"),a=i&&function(){}.name==="something",o=i&&(!e||e&&n(t,"name").configurable);return wi={EXISTS:i,PROPER:a,CONFIGURABLE:o},wi}var Ai,Wv;function E_(){if(Wv)return Ai;Wv=1;var e=j();return Ai=!e(function(){function r(){}return r.prototype.constructor=null,Object.getPrototypeOf(new r)!==r.prototype}),Ai}var $i,Vv;function Hv(){if(Vv)return $i;Vv=1;var e=Y(),r=z(),t=ur(),n=ct(),i=E_(),a=n("IE_PROTO"),o=Object,s=o.prototype;return $i=i?o.getPrototypeOf:function(u){var c=t(u);if(e(c,a))return c[a];var f=c.constructor;return r(f)&&c instanceof f?f.prototype:c instanceof o?s:null},$i}var Di,zv;function Yv(){if(zv)return Di;zv=1;var e=j(),r=z(),t=Q(),n=Ce(),i=Hv(),a=xe(),o=X(),s=ve(),u=o("iterator"),c=!1,f,v,h;[].keys&&(h=[].keys(),"next"in h?(v=i(i(h)),v!==Object.prototype&&(f=v)):c=!0);var l=!t(f)||e(function(){var d={};return f[u].call(d)!==d});return l?f={}:s&&(f=n(f)),r(f[u])||a(f,u,function(){return this}),Di={IteratorPrototype:f,BUGGY_SAFARI_ITERATORS:c},Di}var Ci,Xv;function q_(){if(Xv)return Ci;Xv=1;var e=Yv().IteratorPrototype,r=Ce(),t=Re(),n=Kr(),i=me(),a=function(){return this};return Ci=function(o,s,u,c){var f=s+" Iterator";return o.prototype=r(e,{next:t(+!c,u)}),n(o,f,!1,!0),i[f]=a,o},Ci}var xi,Jv;function I_(){if(Jv)return xi;Jv=1;var e=N(),r=gr();return xi=function(t,n,i){try{return e(r(Object.getOwnPropertyDescriptor(t,n)[i]))}catch{}},xi}var ji,Zv;function O_(){if(Zv)return ji;Zv=1;var e=Q();return ji=function(r){return e(r)||r===null},ji}var Mi,Qv;function R_(){if(Qv)return Mi;Qv=1;var e=O_(),r=String,t=TypeError;return Mi=function(n){if(e(n))return n;throw new t("Can't set "+r(n)+" as a prototype")},Mi}var Ni,rl;function T_(){if(rl)return Ni;rl=1;var e=I_(),r=Q(),t=kr(),n=R_();return Ni=Object.setPrototypeOf||("__proto__"in{}?function(){var i=!1,a={},o;try{o=e(Object.prototype,"__proto__","set"),o(a,[]),i=a instanceof Array}catch{}return function(u,c){return t(u),n(c),r(u)&&(i?o(u,c):u.__proto__=c),u}}():void 0),Ni}var Fi,el;function Li(){if(el)return Fi;el=1;var e=A(),r=nr(),t=ve(),n=S_(),i=z(),a=q_(),o=Hv(),s=T_(),u=Kr(),c=he(),f=xe(),v=X(),h=me(),l=Yv(),d=n.PROPER,p=n.CONFIGURABLE,S=l.IteratorPrototype,g=l.BUGGY_SAFARI_ITERATORS,m=v("iterator"),T="keys",_="values",E="entries",I=function(){return this};return Fi=function(O,y,b,q,R,P,w){a(b,y,q);var M=function(yr){if(yr===R&&qr)return qr;if(!g&&yr&&yr in tr)return tr[yr];switch(yr){case T:return function(){return new b(this,yr)};case _:return function(){return new b(this,yr)};case E:return function(){return new b(this,yr)}}return function(){return new b(this)}},W=y+" Iterator",ie=!1,tr=O.prototype,Er=tr[m]||tr["@@iterator"]||R&&tr[R],qr=!g&&Er||M(R),ae=y==="Array"&&tr.entries||Er,k,Ir,Or;if(ae&&(k=o(ae.call(new O)),k!==Object.prototype&&k.next&&(!t&&o(k)!==S&&(s?s(k,S):i(k[m])||f(k,m,I)),u(k,W,!0,!0),t&&(h[W]=I))),d&&R===_&&Er&&Er.name!==_&&(!t&&p?c(tr,"name",_):(ie=!0,qr=function(){return r(Er,this)})),R)if(Ir={values:M(_),keys:P?qr:M(T),entries:M(E)},w)for(Or in Ir)(g||ie||!(Or in tr))&&f(tr,Or,Ir[Or]);else e({target:y,proto:!0,forced:g||ie},Ir);return(!t||w)&&tr[m]!==qr&&f(tr,m,qr,{name:R}),h[y]=qr,Ir},Fi}var Bi,tl;function ki(){return tl||(tl=1,Bi=function(e,r){return{value:e,done:r}}),Bi}var Ki,nl;function Mr(){if(nl)return Ki;nl=1;var e=mr(),r=Kv(),t=me(),n=je(),i=cr().f,a=Li(),o=ki(),s=ve(),u=U(),c="Array Iterator",f=n.set,v=n.getterFor(c);Ki=a(Array,"Array",function(l,d){f(this,{type:c,target:e(l),index:0,kind:d})},function(){var l=v(this),d=l.target,p=l.index++;if(!d||p>=d.length)return l.target=null,o(void 0,!0);switch(l.kind){case"keys":return o(p,!1);case"values":return o(d[p],!1)}return o([p,d[p]],!1)},"values");var h=t.Arguments=t.Array;if(r("keys"),r("values"),r("entries"),!s&&u&&h.name!=="values")try{i(h,"name",{value:"values"})}catch{}return Ki}var Ui,il;function P_(){return il||(il=1,Ui={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0}),Ui}var al;function Nr(){if(al)return Bv;al=1,Mr();var e=P_(),r=K(),t=Kr(),n=me();for(var i in e)t(r[i],i),n[i]=n.Array;return Bv}var Gi,ol;function sl(){if(ol)return Gi;ol=1;var e=b_();return Nr(),Gi=e,Gi}var ul={},cl;function w_(){if(cl)return ul;cl=1;var e=X(),r=cr().f,t=e("metadata"),n=Function.prototype;return n[t]===void 0&&r(n,t,{value:null}),ul}var fl={},vl;function A_(){return vl||(vl=1,av()),fl}var ll={},hl;function $_(){return hl||(hl=1,fv()),ll}var dl={},pl;function D_(){if(pl)return dl;pl=1;var e=B();return e("metadata"),dl}var Wi,yl;function C_(){if(yl)return Wi;yl=1;var e=sl();return w_(),A_(),$_(),D_(),Wi=e,Wi}var ml={},Vi,gl;function _l(){if(gl)return Vi;gl=1;var e=or(),r=N(),t=e("Symbol"),n=t.keyFor,i=r(t.prototype.valueOf);return Vi=t.isRegisteredSymbol||function(o){try{return n(i(o))!==void 0}catch{return!1}},Vi}var bl;function x_(){if(bl)return ml;bl=1;var e=A(),r=_l();return e({target:"Symbol",stat:!0},{isRegisteredSymbol:r}),ml}var Sl={},Hi,El;function ql(){if(El)return Hi;El=1;for(var e=le(),r=or(),t=N(),n=we(),i=X(),a=r("Symbol"),o=a.isWellKnownSymbol,s=r("Object","getOwnPropertyNames"),u=t(a.prototype.valueOf),c=e("wks"),f=0,v=s(a),h=v.length;f<h;f++)try{var l=v[f];n(a[l])&&i(l)}catch{}return Hi=function(p){if(o&&o(p))return!0;try{for(var S=u(p),g=0,m=s(c),T=m.length;g<T;g++)if(c[m[g]]==S)return!0}catch{}return!1},Hi}var Il;function j_(){if(Il)return Sl;Il=1;var e=A(),r=ql();return e({target:"Symbol",stat:!0,forced:!0},{isWellKnownSymbol:r}),Sl}var Ol={},Rl;function M_(){if(Rl)return Ol;Rl=1;var e=B();return e("customMatcher"),Ol}var Tl={},Pl;function N_(){if(Pl)return Tl;Pl=1;var e=B();return e("observable"),Tl}var wl={},Al;function F_(){if(Al)return wl;Al=1;var e=A(),r=_l();return e({target:"Symbol",stat:!0,name:"isRegisteredSymbol"},{isRegistered:r}),wl}var $l={},Dl;function L_(){if(Dl)return $l;Dl=1;var e=A(),r=ql();return e({target:"Symbol",stat:!0,name:"isWellKnownSymbol",forced:!0},{isWellKnown:r}),$l}var Cl={},xl;function B_(){if(xl)return Cl;xl=1;var e=B();return e("matcher"),Cl}var jl={},Ml;function k_(){if(Ml)return jl;Ml=1;var e=B();return e("metadataKey"),jl}var Nl={},Fl;function K_(){if(Fl)return Nl;Fl=1;var e=B();return e("patternMatch"),Nl}var Ll={},Bl;function U_(){if(Bl)return Ll;Bl=1;var e=B();return e("replaceAll"),Ll}var zi,kl;function G_(){if(kl)return zi;kl=1;var e=C_();return x_(),j_(),M_(),N_(),F_(),L_(),B_(),k_(),K_(),U_(),zi=e,zi}var Yi,Kl;function W_(){return Kl||(Kl=1,Yi=G_()),Yi}var V_=W_(),ht=$(V_),Ul={},Xi,Gl;function H_(){if(Gl)return Xi;Gl=1;var e=N(),r=de(),t=jr(),n=kr(),i=e("".charAt),a=e("".charCodeAt),o=e("".slice),s=function(u){return function(c,f){var v=t(n(c)),h=r(f),l=v.length,d,p;return h<0||h>=l?u?"":void 0:(d=a(v,h),d<55296||d>56319||h+1===l||(p=a(v,h+1))<56320||p>57343?u?i(v,h):d:u?o(v,h,h+2):(d-55296<<10)+(p-56320)+65536)}};return Xi={codeAt:s(!1),charAt:s(!0)},Xi}var Wl;function dt(){if(Wl)return Ul;Wl=1;var e=H_().charAt,r=jr(),t=je(),n=Li(),i=ki(),a="String Iterator",o=t.set,s=t.getterFor(a);return n(String,"String",function(u){o(this,{type:a,string:r(u),index:0})},function(){var c=s(this),f=c.string,v=c.index,h;return v>=f.length?i(void 0,!0):(h=e(f,v),c.index+=h.length,i(h,!1))}),Ul}var Ji,Vl;function z_(){if(Vl)return Ji;Vl=1,Mr(),dt(),mv();var e=lt();return Ji=e.f("iterator"),Ji}var Zi,Hl;function zl(){if(Hl)return Zi;Hl=1;var e=z_();return Nr(),Zi=e,Zi}var Qi,Yl;function Y_(){if(Yl)return Qi;Yl=1;var e=zl();return Qi=e,Qi}var ra,Xl;function X_(){if(Xl)return ra;Xl=1;var e=Y_();return ra=e,ra}var ea,Jl;function J_(){return Jl||(Jl=1,ea=X_()),ea}var Z_=J_(),Q_=$(Z_);function Me(e){"@babel/helpers - typeof";return Me=typeof ht=="function"&&typeof Q_=="symbol"?function(r){return typeof r}:function(r){return r&&typeof ht=="function"&&r.constructor===ht&&r!==ht.prototype?"symbol":typeof r},Me(e)}var ta,Zl;function rb(){if(Zl)return ta;Zl=1,Dv();var e=lt();return ta=e.f("toPrimitive"),ta}var na,Ql;function eb(){if(Ql)return na;Ql=1;var e=rb();return na=e,na}var ia,rh;function tb(){if(rh)return ia;rh=1;var e=eb();return ia=e,ia}var aa,eh;function nb(){if(eh)return aa;eh=1;var e=tb();return aa=e,aa}var oa,th;function ib(){return th||(th=1,oa=nb()),oa}var ab=ib(),ob=$(ab);function sb(e,r){if(Me(e)!="object"||!e)return e;var t=e[ob];if(t!==void 0){var n=t.call(e,r);if(Me(n)!="object")return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return(r==="string"?String:Number)(e)}function ub(e){var r=sb(e,"string");return Me(r)=="symbol"?r:r+""}function fr(e,r,t){return(r=ub(r))in e?Yg(e,r,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[r]=t,e}var nh={},sa,ih;function cb(){if(ih)return sa;ih=1;var e=N(),r=gr(),t=Q(),n=Y(),i=pe(),a=Oe(),o=Function,s=e([].concat),u=e([].join),c={},f=function(v,h,l){if(!n(c,h)){for(var d=[],p=0;p<h;p++)d[p]="a["+p+"]";c[h]=o("C,a","return new C("+u(d,",")+")")}return c[h](v,l)};return sa=a?o.bind:function(h){var l=r(this),d=l.prototype,p=i(arguments,1),S=function(){var m=s(p,i(arguments));return this instanceof S?f(l,m.length,m):l.apply(h,m)};return t(d)&&(S.prototype=d),S},sa}var ah;function fb(){if(ah)return nh;ah=1;var e=A(),r=cb();return e({target:"Function",proto:!0,forced:Function.bind!==r},{bind:r}),nh}var ua,oh;function rr(){if(oh)return ua;oh=1;var e=K(),r=V();return ua=function(t,n){var i=r[t+"Prototype"],a=i&&i[n];if(a)return a;var o=e[t],s=o&&o.prototype;return s&&s[n]},ua}var ca,sh;function vb(){if(sh)return ca;sh=1,fb();var e=rr();return ca=e("Function","bind"),ca}var fa,uh;function lb(){if(uh)return fa;uh=1;var e=H(),r=vb(),t=Function.prototype;return fa=function(n){var i=n.bind;return n===t||e(t,n)&&i===t.bind?r:i},fa}var va,ch;function hb(){if(ch)return va;ch=1;var e=lb();return va=e,va}var la,fh;function db(){return fh||(fh=1,la=hb()),la}var pb=db(),Ur=$(pb),vh={},ha,lh;function yb(){if(lh)return ha;lh=1;var e=gr(),r=ur(),t=nt(),n=_r(),i=TypeError,a="Reduce of empty array with no initial value",o=function(s){return function(u,c,f,v){var h=r(u),l=t(h),d=n(h);if(e(c),d===0&&f<2)throw new i(a);var p=s?d-1:0,S=s?-1:1;if(f<2)for(;;){if(p in l){v=l[p],p+=S;break}if(p+=S,s?p<0:d<=p)throw new i(a)}for(;s?p>=0:d>p;p+=S)p in l&&(v=c(v,l[p],p,h));return v}};return ha={left:o(!1),right:o(!0)},ha}var da,hh;function pt(){if(hh)return da;hh=1;var e=j();return da=function(r,t){var n=[][r];return!!n&&e(function(){n.call(null,t||function(){return 1},1)})},da}var pa,dh;function ph(){if(dh)return pa;dh=1;var e=K(),r=ue(),t=Rr(),n=function(i){return r.slice(0,i.length)===i};return pa=function(){return n("Bun/")?"BUN":n("Cloudflare-Workers")?"CLOUDFLARE":n("Deno/")?"DENO":n("Node.js/")?"NODE":e.Bun&&typeof Bun.version=="string"?"BUN":e.Deno&&typeof Deno.version=="object"?"DENO":t(e.process)==="process"?"NODE":e.window&&e.document?"BROWSER":"REST"}(),pa}var ya,yh;function mb(){if(yh)return ya;yh=1;var e=ph();return ya=e==="NODE",ya}var mh;function gb(){if(mh)return vh;mh=1;var e=A(),r=yb().left,t=pt(),n=Pe(),i=mb(),a=!i&&n>79&&n<83,o=a||!t("reduce");return e({target:"Array",proto:!0,forced:o},{reduce:function(u){var c=arguments.length;return r(this,u,c,c>1?arguments[1]:void 0)}}),vh}var ma,gh;function _b(){if(gh)return ma;gh=1,gb();var e=rr();return ma=e("Array","reduce"),ma}var ga,_h;function bb(){if(_h)return ga;_h=1;var e=H(),r=_b(),t=Array.prototype;return ga=function(n){var i=n.reduce;return n===t||e(t,n)&&i===t.reduce?r:i},ga}var _a,bh;function Sb(){if(bh)return _a;bh=1;var e=bb();return _a=e,_a}var ba,Sh;function Eb(){return Sh||(Sh=1,ba=Sb()),ba}var qb=Eb(),Eh=$(qb),qh={},Ih;function Ib(){if(Ih)return qh;Ih=1;var e=A(),r=ye().filter,t=$e(),n=t("filter");return e({target:"Array",proto:!0,forced:!n},{filter:function(a){return r(this,a,arguments.length>1?arguments[1]:void 0)}}),qh}var Sa,Oh;function Ob(){if(Oh)return Sa;Oh=1,Ib();var e=rr();return Sa=e("Array","filter"),Sa}var Ea,Rh;function Rb(){if(Rh)return Ea;Rh=1;var e=H(),r=Ob(),t=Array.prototype;return Ea=function(n){var i=n.filter;return n===t||e(t,n)&&i===t.filter?r:i},Ea}var qa,Th;function Tb(){if(Th)return qa;Th=1;var e=Rb();return qa=e,qa}var Ia,Ph;function Pb(){return Ph||(Ph=1,Ia=Tb()),Ia}var wb=Pb(),J=$(wb),wh={},Ah;function Ab(){if(Ah)return wh;Ah=1;var e=A(),r=ye().map,t=$e(),n=t("map");return e({target:"Array",proto:!0,forced:!n},{map:function(a){return r(this,a,arguments.length>1?arguments[1]:void 0)}}),wh}var Oa,$h;function $b(){if($h)return Oa;$h=1,Ab();var e=rr();return Oa=e("Array","map"),Oa}var Ra,Dh;function Db(){if(Dh)return Ra;Dh=1;var e=H(),r=$b(),t=Array.prototype;return Ra=function(n){var i=n.map;return n===t||e(t,n)&&i===t.map?r:i},Ra}var Ta,Ch;function Cb(){if(Ch)return Ta;Ch=1;var e=Db();return Ta=e,Ta}var Pa,xh;function xb(){return xh||(xh=1,Pa=Cb()),Pa}var jb=xb(),sr=$(jb),jh={},wa,Mh;function Mb(){if(Mh)return wa;Mh=1;var e=Cr(),r=_r(),t=Ln(),n=Ae(),i=function(a,o,s,u,c,f,v,h){for(var l=c,d=0,p=v?n(v,h):!1,S,g;d<u;)d in s&&(S=p?p(s[d],d,o):s[d],f>0&&e(S)?(g=r(S),l=i(a,o,S,g,l,f-1)-1):(t(l+1),a[l]=S),l++),d++;return l};return wa=i,wa}var Nh;function Nb(){if(Nh)return jh;Nh=1;var e=A(),r=Mb(),t=gr(),n=ur(),i=_r(),a=st();return e({target:"Array",proto:!0},{flatMap:function(s){var u=n(this),c=i(u),f;return t(s),f=a(u,0),f.length=r(f,u,u,c,0,1,s,arguments.length>1?arguments[1]:void 0),f}}),jh}var Fh={},Lh;function Fb(){if(Lh)return Fh;Lh=1;var e=Kv();return e("flatMap"),Fh}var Aa,Bh;function Lb(){if(Bh)return Aa;Bh=1,Nb(),Fb();var e=rr();return Aa=e("Array","flatMap"),Aa}var $a,kh;function Bb(){if(kh)return $a;kh=1;var e=H(),r=Lb(),t=Array.prototype;return $a=function(n){var i=n.flatMap;return n===t||e(t,n)&&i===t.flatMap?r:i},$a}var Da,Kh;function kb(){if(Kh)return Da;Kh=1;var e=Bb();return Da=e,Da}var Ca,Uh;function Kb(){return Uh||(Uh=1,Ca=kb()),Ca}var Ub=Kb(),Gb=$(Ub);function Wb(e){return new Hb(e)}class Vb{constructor(r,t,n){var i,a,o;fr(this,"_listeners",{add:Ur(i=this._add).call(i,this),remove:Ur(a=this._remove).call(a,this),update:Ur(o=this._update).call(o,this)}),this._source=r,this._transformers=t,this._target=n}all(){return this._target.update(this._transformItems(this._source.get())),this}start(){return this._source.on("add",this._listeners.add),this._source.on("remove",this._listeners.remove),this._source.on("update",this._listeners.update),this}stop(){return this._source.off("add",this._listeners.add),this._source.off("remove",this._listeners.remove),this._source.off("update",this._listeners.update),this}_transformItems(r){var t;return Eh(t=this._transformers).call(t,(n,i)=>i(n),r)}_add(r,t){t!=null&&this._target.add(this._transformItems(this._source.get(t.items)))}_update(r,t){t!=null&&this._target.update(this._transformItems(this._source.get(t.items)))}_remove(r,t){t!=null&&this._target.remove(this._transformItems(t.oldData))}}class Hb{constructor(r){fr(this,"_transformers",[]),this._source=r}filter(r){return this._transformers.push(t=>J(t).call(t,r)),this}map(r){return this._transformers.push(t=>sr(t).call(t,r)),this}flatMap(r){return this._transformers.push(t=>Gb(t).call(t,r)),this}to(r){return new Vb(this._source,this._transformers,r)}}var xa,Gh;function zb(){return Gh||(Gh=1,xa=sl()),xa}var Yb=zb(),Xb=$(Yb),Wh={},Vh;function Jb(){if(Vh)return Wh;Vh=1;var e=A(),r=Cr(),t=of(),n=Q(),i=Zn(),a=_r(),o=mr(),s=ot(),u=X(),c=$e(),f=pe(),v=c("slice"),h=u("species"),l=Array,d=Math.max;return e({target:"Array",proto:!0,forced:!v},{slice:function(S,g){var m=o(this),T=a(m),_=i(S,T),E=i(g===void 0?T:g,T),I,O,y;if(r(m)&&(I=m.constructor,t(I)&&(I===l||r(I.prototype))?I=void 0:n(I)&&(I=I[h],I===null&&(I=void 0)),I===l||I===void 0))return f(m,_,E);for(O=new(I===void 0?l:I)(d(E-_,0)),y=0;_<E;_++,y++)_ in m&&s(O,y,m[_]);return O.length=y,O}}),Wh}var ja,Hh;function Zb(){if(Hh)return ja;Hh=1,Jb();var e=rr();return ja=e("Array","slice"),ja}var Ma,zh;function Qb(){if(zh)return Ma;zh=1;var e=H(),r=Zb(),t=Array.prototype;return Ma=function(n){var i=n.slice;return n===t||e(t,n)&&i===t.slice?r:i},Ma}var Na,Yh;function rS(){if(Yh)return Na;Yh=1;var e=Qb();return Na=e,Na}var Fa,Xh;function eS(){return Xh||(Xh=1,Fa=rS()),Fa}var tS=eS(),nS=$(tS),Jh={},La,Zh;function Qh(){if(Zh)return La;Zh=1;var e=or(),r=N(),t=ft(),n=vt(),i=Tr(),a=r([].concat);return La=e("Reflect","ownKeys")||function(s){var u=t.f(i(s)),c=n.f;return c?a(u,c(s)):u},La}var rd;function iS(){if(rd)return Jh;rd=1;var e=A(),r=Qh();return e({target:"Reflect",stat:!0},{ownKeys:r}),Jh}var Ba,ed;function aS(){if(ed)return Ba;ed=1,iS();var e=V();return Ba=e.Reflect.ownKeys,Ba}var ka,td;function oS(){if(td)return ka;td=1;var e=aS();return ka=e,ka}var Ka,nd;function sS(){return nd||(nd=1,Ka=oS()),Ka}var uS=sS(),id=$(uS),ad={},od;function cS(){if(od)return ad;od=1;var e=A(),r=Cr();return e({target:"Array",stat:!0},{isArray:r}),ad}var Ua,sd;function fS(){if(sd)return Ua;sd=1,cS();var e=V();return Ua=e.Array.isArray,Ua}var Ga,ud;function vS(){if(ud)return Ga;ud=1;var e=fS();return Ga=e,Ga}var Wa,cd;function lS(){return cd||(cd=1,Wa=vS()),Wa}var hS=lS(),dr=$(hS),fd={},vd;function dS(){if(vd)return fd;vd=1;var e=A(),r=ur(),t=ut(),n=j(),i=n(function(){t(1)});return e({target:"Object",stat:!0,forced:i},{keys:function(o){return t(r(o))}}),fd}var Va,ld;function pS(){if(ld)return Va;ld=1,dS();var e=V();return Va=e.Object.keys,Va}var Ha,hd;function yS(){if(hd)return Ha;hd=1;var e=pS();return Ha=e,Ha}var za,dd;function mS(){return dd||(dd=1,za=yS()),za}var gS=mS(),Ya=$(gS),pd={},Xa,yd;function _S(){if(yd)return Xa;yd=1;var e=ye().forEach,r=pt(),t=r("forEach");return Xa=t?[].forEach:function(i){return e(this,i,arguments.length>1?arguments[1]:void 0)},Xa}var md;function bS(){if(md)return pd;md=1;var e=A(),r=_S();return e({target:"Array",proto:!0,forced:[].forEach!==r},{forEach:r}),pd}var Ja,gd;function SS(){if(gd)return Ja;gd=1,bS();var e=rr();return Ja=e("Array","forEach"),Ja}var Za,_d;function ES(){if(_d)return Za;_d=1;var e=SS();return Za=e,Za}var Qa,bd;function qS(){if(bd)return Qa;bd=1;var e=xr(),r=Y(),t=H(),n=ES(),i=Array.prototype,a={DOMTokenList:!0,NodeList:!0};return Qa=function(o){var s=o.forEach;return o===i||t(i,o)&&s===i.forEach||r(a,e(o))?n:s},Qa}var ro,Sd;function IS(){return Sd||(Sd=1,ro=qS()),ro}var OS=IS(),Fr=$(OS),Ed={},qd;function RS(){if(qd)return Ed;qd=1;var e=A(),r=N(),t=Cr(),n=r([].reverse),i=[1,2];return e({target:"Array",proto:!0,forced:String(i)===String(i.reverse())},{reverse:function(){return t(this)&&(this.length=this.length),n(this)}}),Ed}var eo,Id;function TS(){if(Id)return eo;Id=1,RS();var e=rr();return eo=e("Array","reverse"),eo}var to,Od;function PS(){if(Od)return to;Od=1;var e=H(),r=TS(),t=Array.prototype;return to=function(n){var i=n.reverse;return n===t||e(t,n)&&i===t.reverse?r:i},to}var no,Rd;function wS(){if(Rd)return no;Rd=1;var e=PS();return no=e,no}var io,Td;function AS(){return Td||(Td=1,io=wS()),io}var $S=AS(),DS=$($S),Pd={},ao,wd;function CS(){if(wd)return ao;wd=1;var e=U(),r=Cr(),t=TypeError,n=Object.getOwnPropertyDescriptor,i=e&&!function(){if(this!==void 0)return!0;try{Object.defineProperty([],"length",{writable:!1}).length=1}catch(a){return a instanceof TypeError}}();return ao=i?function(a,o){if(r(a)&&!n(a,"length").writable)throw new t("Cannot set read only .length");return a.length=o}:function(a,o){return a.length=o},ao}var oo,Ad;function $d(){if(Ad)return oo;Ad=1;var e=fe(),r=TypeError;return oo=function(t,n){if(!delete t[n])throw new r("Cannot delete property "+e(n)+" of "+e(t))},oo}var Dd;function xS(){if(Dd)return Pd;Dd=1;var e=A(),r=ur(),t=Zn(),n=de(),i=_r(),a=CS(),o=Ln(),s=st(),u=ot(),c=$d(),f=$e(),v=f("splice"),h=Math.max,l=Math.min;return e({target:"Array",proto:!0,forced:!v},{splice:function(p,S){var g=r(this),m=i(g),T=t(p,m),_=arguments.length,E,I,O,y,b,q;for(_===0?E=I=0:_===1?(E=0,I=m-T):(E=_-2,I=l(h(n(S),0),m-T)),o(m+E-I),O=s(g,I),y=0;y<I;y++)b=T+y,b in g&&u(O,y,g[b]);if(O.length=I,E<I){for(y=T;y<m-I;y++)b=y+I,q=y+E,b in g?g[q]=g[b]:c(g,q);for(y=m;y>m-I+E;y--)c(g,y-1)}else if(E>I)for(y=m-I;y>T;y--)b=y+I-1,q=y+E-1,b in g?g[q]=g[b]:c(g,q);for(y=0;y<E;y++)g[y+T]=arguments[y+2];return a(g,m-I+E),O}}),Pd}var so,Cd;function jS(){if(Cd)return so;Cd=1,xS();var e=rr();return so=e("Array","splice"),so}var uo,xd;function MS(){if(xd)return uo;xd=1;var e=H(),r=jS(),t=Array.prototype;return uo=function(n){var i=n.splice;return n===t||e(t,n)&&i===t.splice?r:i},uo}var co,jd;function NS(){if(jd)return co;jd=1;var e=MS();return co=e,co}var fo,Md;function FS(){return Md||(Md=1,fo=NS()),fo}var LS=FS(),Nd=$(LS),Fd={},vo,Ld;function BS(){if(Ld)return vo;Ld=1;var e=U(),r=N(),t=nr(),n=j(),i=ut(),a=vt(),o=kt(),s=ur(),u=nt(),c=Object.assign,f=Object.defineProperty,v=r([].concat);return vo=!c||n(function(){if(e&&c({b:1},c(f({},"a",{enumerable:!0,get:function(){f(this,"b",{value:3,enumerable:!1})}}),{b:2})).b!==1)return!0;var h={},l={},d=Symbol("assign detection"),p="abcdefghijklmnopqrst";return h[d]=7,p.split("").forEach(function(S){l[S]=S}),c({},h)[d]!==7||i(c({},l)).join("")!==p})?function(l,d){for(var p=s(l),S=arguments.length,g=1,m=a.f,T=o.f;S>g;)for(var _=u(arguments[g++]),E=m?v(i(_),m(_)):i(_),I=E.length,O=0,y;I>O;)y=E[O++],(!e||t(T,_,y))&&(p[y]=_[y]);return p}:c,vo}var Bd;function kS(){if(Bd)return Fd;Bd=1;var e=A(),r=BS();return e({target:"Object",stat:!0,arity:2,forced:Object.assign!==r},{assign:r}),Fd}var lo,kd;function KS(){if(kd)return lo;kd=1,kS();var e=V();return lo=e.Object.assign,lo}var ho,Kd;function US(){if(Kd)return ho;Kd=1;var e=KS();return ho=e,ho}var po,Ud;function GS(){return Ud||(Ud=1,po=US()),po}var WS=GS(),Gd=$(WS),yo,Wd;function VS(){if(Wd)return yo;Wd=1,vf();var e=rr();return yo=e("Array","concat"),yo}var mo,Vd;function HS(){if(Vd)return mo;Vd=1;var e=H(),r=VS(),t=Array.prototype;return mo=function(n){var i=n.concat;return n===t||e(t,n)&&i===t.concat?r:i},mo}var go,Hd;function zS(){if(Hd)return go;Hd=1;var e=HS();return go=e,go}var _o,zd;function YS(){return zd||(zd=1,_o=zS()),_o}var XS=YS(),JS=$(XS),Yd={},Xd;function ZS(){if(Xd)return Yd;Xd=1;var e=A(),r=U(),t=Ce();return e({target:"Object",stat:!0,sham:!r},{create:t}),Yd}var bo,Jd;function QS(){if(Jd)return bo;Jd=1,ZS();var e=V(),r=e.Object;return bo=function(n,i){return r.create(n,i)},bo}var So,Zd;function rE(){if(Zd)return So;Zd=1;var e=QS();return So=e,So}var Eo,Qd;function eE(){return Qd||(Qd=1,Eo=rE()),Eo}var tE=eE(),nE=$(tE),rp={},qo,ep;function iE(){if(ep)return qo;ep=1;var e=de(),r=jr(),t=kr(),n=RangeError;return qo=function(a){var o=r(t(this)),s="",u=e(a);if(u<0||u===1/0)throw new n("Wrong number of repetitions");for(;u>0;(u>>>=1)&&(o+=o))u&1&&(s+=o);return s},qo}var Io,tp;function aE(){if(tp)return Io;tp=1;var e=N(),r=Jc(),t=jr(),n=iE(),i=kr(),a=e(n),o=e("".slice),s=Math.ceil,u=function(c){return function(f,v,h){var l=t(i(f)),d=r(v),p=l.length,S=h===void 0?" ":t(h),g,m;return d<=p||S===""?l:(g=d-p,m=a(S,s(g/S.length)),m.length>g&&(m=o(m,0,g)),c?l+m:m+l)}};return Io={start:u(!1),end:u(!0)},Io}var Oo,np;function oE(){if(np)return Oo;np=1;var e=N(),r=j(),t=aE().start,n=RangeError,i=isFinite,a=Math.abs,o=Date.prototype,s=o.toISOString,u=e(o.getTime),c=e(o.getUTCDate),f=e(o.getUTCFullYear),v=e(o.getUTCHours),h=e(o.getUTCMilliseconds),l=e(o.getUTCMinutes),d=e(o.getUTCMonth),p=e(o.getUTCSeconds);return Oo=r(function(){return s.call(new Date(-5e13-1))!=="0385-07-25T07:06:39.999Z"})||!r(function(){s.call(new Date(NaN))})?function(){if(!i(u(this)))throw new n("Invalid time value");var g=this,m=f(g),T=h(g),_=m<0?"-":m>9999?"+":"";return _+t(a(m),_?6:4,0)+"-"+t(d(g)+1,2,0)+"-"+t(c(g),2,0)+"T"+t(v(g),2,0)+":"+t(l(g),2,0)+":"+t(p(g),2,0)+"."+t(T,3,0)+"Z"}:s,Oo}var ip;function sE(){if(ip)return rp;ip=1;var e=A(),r=nr(),t=ur(),n=Ic(),i=oE(),a=Rr(),o=j(),s=o(function(){return new Date(NaN).toJSON()!==null||r(Date.prototype.toJSON,{toISOString:function(){return 1}})!==1});return e({target:"Date",proto:!0,forced:s},{toJSON:function(c){var f=t(this),v=n(f,"number");return typeof v=="number"&&!isFinite(v)?null:!("toISOString"in f)&&a(f)==="Date"?r(i,f):f.toISOString()}}),rp}var Ro,ap;function uE(){if(ap)return Ro;ap=1,sE(),Zf();var e=V(),r=tt();return e.JSON||(e.JSON={stringify:JSON.stringify}),Ro=function(n,i,a){return r(e.JSON.stringify,null,arguments)},Ro}var To,op;function cE(){if(op)return To;op=1;var e=uE();return To=e,To}var Po,sp;function fE(){return sp||(sp=1,Po=cE()),Po}var vE=fE(),lE=$(vE),up={},cp={},wo,fp;function hE(){if(fp)return wo;fp=1;var e=TypeError;return wo=function(r,t){if(r<t)throw new e("Not enough arguments");return r},wo}var Ao,vp;function lp(){if(vp)return Ao;vp=1;var e=K(),r=tt(),t=z(),n=ph(),i=ue(),a=pe(),o=hE(),s=e.Function,u=/MSIE .\./.test(i)||n==="BUN"&&function(){var c=e.Bun.version.split(".");return c.length<3||c[0]==="0"&&(c[1]<3||c[1]==="3"&&c[2]==="0")}();return Ao=function(c,f){var v=f?2:1;return u?function(h,l){var d=o(arguments.length,1)>v,p=t(h)?h:s(h),S=d?a(arguments,v):[],g=d?function(){r(p,this,S)}:p;return f?c(g,l):c(g)}:c},Ao}var hp;function dE(){if(hp)return cp;hp=1;var e=A(),r=K(),t=lp(),n=t(r.setInterval,!0);return e({global:!0,bind:!0,forced:r.setInterval!==n},{setInterval:n}),cp}var dp={},pp;function pE(){if(pp)return dp;pp=1;var e=A(),r=K(),t=lp(),n=t(r.setTimeout,!0);return e({global:!0,bind:!0,forced:r.setTimeout!==n},{setTimeout:n}),dp}var yp;function yE(){return yp||(yp=1,dE(),pE()),up}var $o,mp;function mE(){if(mp)return $o;mp=1,yE();var e=V();return $o=e.setTimeout,$o}var Do,gp;function gE(){return gp||(gp=1,Do=mE()),Do}var _E=gE(),bE=$(_E),Co={exports:{}},_p;function SE(){return _p||(_p=1,function(e){function r(n){if(n)return t(n);this._callbacks=new Map}function t(n){return Object.assign(n,r.prototype),n._callbacks=new Map,n}r.prototype.on=function(n,i){const a=this._callbacks.get(n)??[];return a.push(i),this._callbacks.set(n,a),this},r.prototype.once=function(n,i){const a=(...o)=>{this.off(n,a),i.apply(this,o)};return a.fn=i,this.on(n,a),this},r.prototype.off=function(n,i){if(n===void 0&&i===void 0)return this._callbacks.clear(),this;if(i===void 0)return this._callbacks.delete(n),this;const a=this._callbacks.get(n);if(a){for(const[o,s]of a.entries())if(s===i||s.fn===i){a.splice(o,1);break}a.length===0?this._callbacks.delete(n):this._callbacks.set(n,a)}return this},r.prototype.emit=function(n,...i){const a=this._callbacks.get(n);if(a){const o=[...a];for(const s of o)s.apply(this,i)}return this},r.prototype.listeners=function(n){return this._callbacks.get(n)??[]},r.prototype.listenerCount=function(n){if(n)return this.listeners(n).length;let i=0;for(const a of this._callbacks.values())i+=a.length;return i},r.prototype.hasListeners=function(n){return this.listenerCount(n)>0},r.prototype.addEventListener=r.prototype.on,r.prototype.removeListener=r.prototype.off,r.prototype.removeEventListener=r.prototype.off,r.prototype.removeAllListeners=r.prototype.off,e.exports=r}(Co)),Co.exports}var EE=SE(),qE=$(EE);/*! Hammer.JS - v2.0.17-rc - 2019-12-16
 * http://naver.github.io/egjs
 *
 * Forked By Naver egjs
 * Copyright (c) hammerjs
 * Licensed under the MIT license */function pr(){return pr=Object.assign||function(e){for(var r=1;r<arguments.length;r++){var t=arguments[r];for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])}return e},pr.apply(this,arguments)}function vr(e,r){e.prototype=Object.create(r.prototype),e.prototype.constructor=e,e.__proto__=r}function yt(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}var xo;typeof Object.assign!="function"?xo=function(r){if(r==null)throw new TypeError("Cannot convert undefined or null to object");for(var t=Object(r),n=1;n<arguments.length;n++){var i=arguments[n];if(i!=null)for(var a in i)i.hasOwnProperty(a)&&(t[a]=i[a])}return t}:xo=Object.assign;var Gr=xo,bp=["","webkit","Moz","MS","ms","o"],IE=typeof document>"u"?{style:{}}:document.createElement("div"),OE="function",ge=Math.round,Wr=Math.abs,jo=Date.now;function mt(e,r){for(var t,n,i=r[0].toUpperCase()+r.slice(1),a=0;a<bp.length;){if(t=bp[a],n=t?t+i:r,n in e)return n;a++}}var Pr;typeof window>"u"?Pr={}:Pr=window;var Sp=mt(IE.style,"touchAction"),Ep=Sp!==void 0;function RE(){if(!Ep)return!1;var e={},r=Pr.CSS&&Pr.CSS.supports;return["auto","manipulation","pan-y","pan-x","pan-x pan-y","none"].forEach(function(t){return e[t]=r?Pr.CSS.supports("touch-action",t):!0}),e}var qp="compute",Ip="auto",Mo="manipulation",Vr="none",Ne="pan-x",Fe="pan-y",gt=RE(),TE=/mobile|tablet|ip(ad|hone|od)|android/i,Op="ontouchstart"in Pr,PE=mt(Pr,"PointerEvent")!==void 0,wE=Op&&TE.test(navigator.userAgent),Le="touch",AE="pen",No="mouse",$E="kinect",DE=25,er=1,Hr=2,G=4,ir=8,_t=1,Be=2,ke=4,Ke=8,_e=16,br=Be|ke,zr=Ke|_e,Rp=br|zr,Tp=["x","y"],bt=["clientX","clientY"];function wr(e,r,t){var n;if(e)if(e.forEach)e.forEach(r,t);else if(e.length!==void 0)for(n=0;n<e.length;)r.call(t,e[n],n,e),n++;else for(n in e)e.hasOwnProperty(n)&&r.call(t,e[n],n,e)}function St(e,r){return typeof e===OE?e.apply(r&&r[0]||void 0,r):e}function Yr(e,r){return e.indexOf(r)>-1}function CE(e){if(Yr(e,Vr))return Vr;var r=Yr(e,Ne),t=Yr(e,Fe);return r&&t?Vr:r||t?r?Ne:Fe:Yr(e,Mo)?Mo:Ip}var Pp=function(){function e(t,n){this.manager=t,this.set(n)}var r=e.prototype;return r.set=function(n){n===qp&&(n=this.compute()),Ep&&this.manager.element.style&&gt[n]&&(this.manager.element.style[Sp]=n),this.actions=n.toLowerCase().trim()},r.update=function(){this.set(this.manager.options.touchAction)},r.compute=function(){var n=[];return wr(this.manager.recognizers,function(i){St(i.options.enable,[i])&&(n=n.concat(i.getTouchAction()))}),CE(n.join(" "))},r.preventDefaults=function(n){var i=n.srcEvent,a=n.offsetDirection;if(this.manager.session.prevented){i.preventDefault();return}var o=this.actions,s=Yr(o,Vr)&&!gt[Vr],u=Yr(o,Fe)&&!gt[Fe],c=Yr(o,Ne)&&!gt[Ne];if(s){var f=n.pointers.length===1,v=n.distance<2,h=n.deltaTime<250;if(f&&v&&h)return}if(!(c&&u)&&(s||u&&a&br||c&&a&zr))return this.preventSrc(i)},r.preventSrc=function(n){this.manager.session.prevented=!0,n.preventDefault()},e}();function Fo(e,r){for(;e;){if(e===r)return!0;e=e.parentNode}return!1}function wp(e){var r=e.length;if(r===1)return{x:ge(e[0].clientX),y:ge(e[0].clientY)};for(var t=0,n=0,i=0;i<r;)t+=e[i].clientX,n+=e[i].clientY,i++;return{x:ge(t/r),y:ge(n/r)}}function Ap(e){for(var r=[],t=0;t<e.pointers.length;)r[t]={clientX:ge(e.pointers[t].clientX),clientY:ge(e.pointers[t].clientY)},t++;return{timeStamp:jo(),pointers:r,center:wp(r),deltaX:e.deltaX,deltaY:e.deltaY}}function Et(e,r,t){t||(t=Tp);var n=r[t[0]]-e[t[0]],i=r[t[1]]-e[t[1]];return Math.sqrt(n*n+i*i)}function Lo(e,r,t){t||(t=Tp);var n=r[t[0]]-e[t[0]],i=r[t[1]]-e[t[1]];return Math.atan2(i,n)*180/Math.PI}function $p(e,r){return e===r?_t:Wr(e)>=Wr(r)?e<0?Be:ke:r<0?Ke:_e}function xE(e,r){var t=r.center,n=e.offsetDelta||{},i=e.prevDelta||{},a=e.prevInput||{};(r.eventType===er||a.eventType===G)&&(i=e.prevDelta={x:a.deltaX||0,y:a.deltaY||0},n=e.offsetDelta={x:t.x,y:t.y}),r.deltaX=i.x+(t.x-n.x),r.deltaY=i.y+(t.y-n.y)}function Dp(e,r,t){return{x:r/e||0,y:t/e||0}}function jE(e,r){return Et(r[0],r[1],bt)/Et(e[0],e[1],bt)}function ME(e,r){return Lo(r[1],r[0],bt)+Lo(e[1],e[0],bt)}function NE(e,r){var t=e.lastInterval||r,n=r.timeStamp-t.timeStamp,i,a,o,s;if(r.eventType!==ir&&(n>DE||t.velocity===void 0)){var u=r.deltaX-t.deltaX,c=r.deltaY-t.deltaY,f=Dp(n,u,c);a=f.x,o=f.y,i=Wr(f.x)>Wr(f.y)?f.x:f.y,s=$p(u,c),e.lastInterval=r}else i=t.velocity,a=t.velocityX,o=t.velocityY,s=t.direction;r.velocity=i,r.velocityX=a,r.velocityY=o,r.direction=s}function FE(e,r){var t=e.session,n=r.pointers,i=n.length;t.firstInput||(t.firstInput=Ap(r)),i>1&&!t.firstMultiple?t.firstMultiple=Ap(r):i===1&&(t.firstMultiple=!1);var a=t.firstInput,o=t.firstMultiple,s=o?o.center:a.center,u=r.center=wp(n);r.timeStamp=jo(),r.deltaTime=r.timeStamp-a.timeStamp,r.angle=Lo(s,u),r.distance=Et(s,u),xE(t,r),r.offsetDirection=$p(r.deltaX,r.deltaY);var c=Dp(r.deltaTime,r.deltaX,r.deltaY);r.overallVelocityX=c.x,r.overallVelocityY=c.y,r.overallVelocity=Wr(c.x)>Wr(c.y)?c.x:c.y,r.scale=o?jE(o.pointers,n):1,r.rotation=o?ME(o.pointers,n):0,r.maxPointers=t.prevInput?r.pointers.length>t.prevInput.maxPointers?r.pointers.length:t.prevInput.maxPointers:r.pointers.length,NE(t,r);var f=e.element,v=r.srcEvent,h;v.composedPath?h=v.composedPath()[0]:v.path?h=v.path[0]:h=v.target,Fo(h,f)&&(f=h),r.target=f}function LE(e,r,t){var n=t.pointers.length,i=t.changedPointers.length,a=r&er&&n-i===0,o=r&(G|ir)&&n-i===0;t.isFirst=!!a,t.isFinal=!!o,a&&(e.session={}),t.eventType=r,FE(e,t),e.emit("hammer.input",t),e.recognize(t),e.session.prevInput=t}function Ue(e){return e.trim().split(/\s+/g)}function Ge(e,r,t){wr(Ue(r),function(n){e.addEventListener(n,t,!1)})}function We(e,r,t){wr(Ue(r),function(n){e.removeEventListener(n,t,!1)})}function Cp(e){var r=e.ownerDocument||e;return r.defaultView||r.parentWindow||window}var be=function(){function e(t,n){var i=this;this.manager=t,this.callback=n,this.element=t.element,this.target=t.options.inputTarget,this.domHandler=function(a){St(t.options.enable,[t])&&i.handler(a)},this.init()}var r=e.prototype;return r.handler=function(){},r.init=function(){this.evEl&&Ge(this.element,this.evEl,this.domHandler),this.evTarget&&Ge(this.target,this.evTarget,this.domHandler),this.evWin&&Ge(Cp(this.element),this.evWin,this.domHandler)},r.destroy=function(){this.evEl&&We(this.element,this.evEl,this.domHandler),this.evTarget&&We(this.target,this.evTarget,this.domHandler),this.evWin&&We(Cp(this.element),this.evWin,this.domHandler)},e}();function Xr(e,r,t){if(e.indexOf&&!t)return e.indexOf(r);for(var n=0;n<e.length;){if(t&&e[n][t]==r||!t&&e[n]===r)return n;n++}return-1}var BE={pointerdown:er,pointermove:Hr,pointerup:G,pointercancel:ir,pointerout:ir},kE={2:Le,3:AE,4:No,5:$E},xp="pointerdown",jp="pointermove pointerup pointercancel";Pr.MSPointerEvent&&!Pr.PointerEvent&&(xp="MSPointerDown",jp="MSPointerMove MSPointerUp MSPointerCancel");var Mp=function(e){vr(r,e);function r(){var n,i=r.prototype;return i.evEl=xp,i.evWin=jp,n=e.apply(this,arguments)||this,n.store=n.manager.session.pointerEvents=[],n}var t=r.prototype;return t.handler=function(i){var a=this.store,o=!1,s=i.type.toLowerCase().replace("ms",""),u=BE[s],c=kE[i.pointerType]||i.pointerType,f=c===Le,v=Xr(a,i.pointerId,"pointerId");u&er&&(i.button===0||f)?v<0&&(a.push(i),v=a.length-1):u&(G|ir)&&(o=!0),!(v<0)&&(a[v]=i,this.callback(this.manager,u,{pointers:a,changedPointers:[i],pointerType:c,srcEvent:i}),o&&a.splice(v,1))},r}(be);function Ve(e){return Array.prototype.slice.call(e,0)}function Bo(e,r,t){for(var n=[],i=[],a=0;a<e.length;){var o=r?e[a][r]:e[a];Xr(i,o)<0&&n.push(e[a]),i[a]=o,a++}return t&&(r?n=n.sort(function(s,u){return s[r]>u[r]}):n=n.sort()),n}var KE={touchstart:er,touchmove:Hr,touchend:G,touchcancel:ir},UE="touchstart touchmove touchend touchcancel",ko=function(e){vr(r,e);function r(){var n;return r.prototype.evTarget=UE,n=e.apply(this,arguments)||this,n.targetIds={},n}var t=r.prototype;return t.handler=function(i){var a=KE[i.type],o=GE.call(this,i,a);o&&this.callback(this.manager,a,{pointers:o[0],changedPointers:o[1],pointerType:Le,srcEvent:i})},r}(be);function GE(e,r){var t=Ve(e.touches),n=this.targetIds;if(r&(er|Hr)&&t.length===1)return n[t[0].identifier]=!0,[t,t];var i,a,o=Ve(e.changedTouches),s=[],u=this.target;if(a=t.filter(function(c){return Fo(c.target,u)}),r===er)for(i=0;i<a.length;)n[a[i].identifier]=!0,i++;for(i=0;i<o.length;)n[o[i].identifier]&&s.push(o[i]),r&(G|ir)&&delete n[o[i].identifier],i++;if(s.length)return[Bo(a.concat(s),"identifier",!0),s]}var WE={mousedown:er,mousemove:Hr,mouseup:G},VE="mousedown",HE="mousemove mouseup",Ko=function(e){vr(r,e);function r(){var n,i=r.prototype;return i.evEl=VE,i.evWin=HE,n=e.apply(this,arguments)||this,n.pressed=!1,n}var t=r.prototype;return t.handler=function(i){var a=WE[i.type];a&er&&i.button===0&&(this.pressed=!0),a&Hr&&i.which!==1&&(a=G),this.pressed&&(a&G&&(this.pressed=!1),this.callback(this.manager,a,{pointers:[i],changedPointers:[i],pointerType:No,srcEvent:i}))},r}(be),zE=2500,Np=25;function Fp(e){var r=e.changedPointers,t=r[0];if(t.identifier===this.primaryTouch){var n={x:t.clientX,y:t.clientY},i=this.lastTouches;this.lastTouches.push(n);var a=function(){var s=i.indexOf(n);s>-1&&i.splice(s,1)};setTimeout(a,zE)}}function YE(e,r){e&er?(this.primaryTouch=r.changedPointers[0].identifier,Fp.call(this,r)):e&(G|ir)&&Fp.call(this,r)}function XE(e){for(var r=e.srcEvent.clientX,t=e.srcEvent.clientY,n=0;n<this.lastTouches.length;n++){var i=this.lastTouches[n],a=Math.abs(r-i.x),o=Math.abs(t-i.y);if(a<=Np&&o<=Np)return!0}return!1}var Lp=function(){var e=function(r){vr(t,r);function t(i,a){var o;return o=r.call(this,i,a)||this,o.handler=function(s,u,c){var f=c.pointerType===Le,v=c.pointerType===No;if(!(v&&c.sourceCapabilities&&c.sourceCapabilities.firesTouchEvents)){if(f)YE.call(yt(yt(o)),u,c);else if(v&&XE.call(yt(yt(o)),c))return;o.callback(s,u,c)}},o.touch=new ko(o.manager,o.handler),o.mouse=new Ko(o.manager,o.handler),o.primaryTouch=null,o.lastTouches=[],o}var n=t.prototype;return n.destroy=function(){this.touch.destroy(),this.mouse.destroy()},t}(be);return e}();function JE(e){var r,t=e.options.inputClass;return t?r=t:PE?r=Mp:wE?r=ko:Op?r=Lp:r=Ko,new r(e,LE)}function Se(e,r,t){return Array.isArray(e)?(wr(e,t[r],t),!0):!1}var qt=1,lr=2,Ee=4,Lr=8,Ar=Lr,He=16,Sr=32,ZE=1;function QE(){return ZE++}function It(e,r){var t=r.manager;return t?t.get(e):e}function Bp(e){return e&He?"cancel":e&Lr?"end":e&Ee?"move":e&lr?"start":""}var ze=function(){function e(t){t===void 0&&(t={}),this.options=pr({enable:!0},t),this.id=QE(),this.manager=null,this.state=qt,this.simultaneous={},this.requireFail=[]}var r=e.prototype;return r.set=function(n){return Gr(this.options,n),this.manager&&this.manager.touchAction.update(),this},r.recognizeWith=function(n){if(Se(n,"recognizeWith",this))return this;var i=this.simultaneous;return n=It(n,this),i[n.id]||(i[n.id]=n,n.recognizeWith(this)),this},r.dropRecognizeWith=function(n){return Se(n,"dropRecognizeWith",this)?this:(n=It(n,this),delete this.simultaneous[n.id],this)},r.requireFailure=function(n){if(Se(n,"requireFailure",this))return this;var i=this.requireFail;return n=It(n,this),Xr(i,n)===-1&&(i.push(n),n.requireFailure(this)),this},r.dropRequireFailure=function(n){if(Se(n,"dropRequireFailure",this))return this;n=It(n,this);var i=Xr(this.requireFail,n);return i>-1&&this.requireFail.splice(i,1),this},r.hasRequireFailures=function(){return this.requireFail.length>0},r.canRecognizeWith=function(n){return!!this.simultaneous[n.id]},r.emit=function(n){var i=this,a=this.state;function o(s){i.manager.emit(s,n)}a<Lr&&o(i.options.event+Bp(a)),o(i.options.event),n.additionalEvent&&o(n.additionalEvent),a>=Lr&&o(i.options.event+Bp(a))},r.tryEmit=function(n){if(this.canEmit())return this.emit(n);this.state=Sr},r.canEmit=function(){for(var n=0;n<this.requireFail.length;){if(!(this.requireFail[n].state&(Sr|qt)))return!1;n++}return!0},r.recognize=function(n){var i=Gr({},n);if(!St(this.options.enable,[this,i])){this.reset(),this.state=Sr;return}this.state&(Ar|He|Sr)&&(this.state=qt),this.state=this.process(i),this.state&(lr|Ee|Lr|He)&&this.tryEmit(i)},r.process=function(n){},r.getTouchAction=function(){},r.reset=function(){},e}(),Uo=function(e){vr(r,e);function r(n){var i;return n===void 0&&(n={}),i=e.call(this,pr({event:"tap",pointers:1,taps:1,interval:300,time:250,threshold:9,posThreshold:10},n))||this,i.pTime=!1,i.pCenter=!1,i._timer=null,i._input=null,i.count=0,i}var t=r.prototype;return t.getTouchAction=function(){return[Mo]},t.process=function(i){var a=this,o=this.options,s=i.pointers.length===o.pointers,u=i.distance<o.threshold,c=i.deltaTime<o.time;if(this.reset(),i.eventType&er&&this.count===0)return this.failTimeout();if(u&&c&&s){if(i.eventType!==G)return this.failTimeout();var f=this.pTime?i.timeStamp-this.pTime<o.interval:!0,v=!this.pCenter||Et(this.pCenter,i.center)<o.posThreshold;this.pTime=i.timeStamp,this.pCenter=i.center,!v||!f?this.count=1:this.count+=1,this._input=i;var h=this.count%o.taps;if(h===0)return this.hasRequireFailures()?(this._timer=setTimeout(function(){a.state=Ar,a.tryEmit()},o.interval),lr):Ar}return Sr},t.failTimeout=function(){var i=this;return this._timer=setTimeout(function(){i.state=Sr},this.options.interval),Sr},t.reset=function(){clearTimeout(this._timer)},t.emit=function(){this.state===Ar&&(this._input.tapCount=this.count,this.manager.emit(this.options.event,this._input))},r}(ze),qe=function(e){vr(r,e);function r(n){return n===void 0&&(n={}),e.call(this,pr({pointers:1},n))||this}var t=r.prototype;return t.attrTest=function(i){var a=this.options.pointers;return a===0||i.pointers.length===a},t.process=function(i){var a=this.state,o=i.eventType,s=a&(lr|Ee),u=this.attrTest(i);return s&&(o&ir||!u)?a|He:s||u?o&G?a|Lr:a&lr?a|Ee:lr:Sr},r}(ze);function kp(e){return e===_e?"down":e===Ke?"up":e===Be?"left":e===ke?"right":""}var Go=function(e){vr(r,e);function r(n){var i;return n===void 0&&(n={}),i=e.call(this,pr({event:"pan",threshold:10,pointers:1,direction:Rp},n))||this,i.pX=null,i.pY=null,i}var t=r.prototype;return t.getTouchAction=function(){var i=this.options.direction,a=[];return i&br&&a.push(Fe),i&zr&&a.push(Ne),a},t.directionTest=function(i){var a=this.options,o=!0,s=i.distance,u=i.direction,c=i.deltaX,f=i.deltaY;return u&a.direction||(a.direction&br?(u=c===0?_t:c<0?Be:ke,o=c!==this.pX,s=Math.abs(i.deltaX)):(u=f===0?_t:f<0?Ke:_e,o=f!==this.pY,s=Math.abs(i.deltaY))),i.direction=u,o&&s>a.threshold&&u&a.direction},t.attrTest=function(i){return qe.prototype.attrTest.call(this,i)&&(this.state&lr||!(this.state&lr)&&this.directionTest(i))},t.emit=function(i){this.pX=i.deltaX,this.pY=i.deltaY;var a=kp(i.direction);a&&(i.additionalEvent=this.options.event+a),e.prototype.emit.call(this,i)},r}(qe),Kp=function(e){vr(r,e);function r(n){return n===void 0&&(n={}),e.call(this,pr({event:"swipe",threshold:10,velocity:.3,direction:br|zr,pointers:1},n))||this}var t=r.prototype;return t.getTouchAction=function(){return Go.prototype.getTouchAction.call(this)},t.attrTest=function(i){var a=this.options.direction,o;return a&(br|zr)?o=i.overallVelocity:a&br?o=i.overallVelocityX:a&zr&&(o=i.overallVelocityY),e.prototype.attrTest.call(this,i)&&a&i.offsetDirection&&i.distance>this.options.threshold&&i.maxPointers===this.options.pointers&&Wr(o)>this.options.velocity&&i.eventType&G},t.emit=function(i){var a=kp(i.offsetDirection);a&&this.manager.emit(this.options.event+a,i),this.manager.emit(this.options.event,i)},r}(qe),Up=function(e){vr(r,e);function r(n){return n===void 0&&(n={}),e.call(this,pr({event:"pinch",threshold:0,pointers:2},n))||this}var t=r.prototype;return t.getTouchAction=function(){return[Vr]},t.attrTest=function(i){return e.prototype.attrTest.call(this,i)&&(Math.abs(i.scale-1)>this.options.threshold||this.state&lr)},t.emit=function(i){if(i.scale!==1){var a=i.scale<1?"in":"out";i.additionalEvent=this.options.event+a}e.prototype.emit.call(this,i)},r}(qe),Gp=function(e){vr(r,e);function r(n){return n===void 0&&(n={}),e.call(this,pr({event:"rotate",threshold:0,pointers:2},n))||this}var t=r.prototype;return t.getTouchAction=function(){return[Vr]},t.attrTest=function(i){return e.prototype.attrTest.call(this,i)&&(Math.abs(i.rotation)>this.options.threshold||this.state&lr)},r}(qe),Wp=function(e){vr(r,e);function r(n){var i;return n===void 0&&(n={}),i=e.call(this,pr({event:"press",pointers:1,time:251,threshold:9},n))||this,i._timer=null,i._input=null,i}var t=r.prototype;return t.getTouchAction=function(){return[Ip]},t.process=function(i){var a=this,o=this.options,s=i.pointers.length===o.pointers,u=i.distance<o.threshold,c=i.deltaTime>o.time;if(this._input=i,!u||!s||i.eventType&(G|ir)&&!c)this.reset();else if(i.eventType&er)this.reset(),this._timer=setTimeout(function(){a.state=Ar,a.tryEmit()},o.time);else if(i.eventType&G)return Ar;return Sr},t.reset=function(){clearTimeout(this._timer)},t.emit=function(i){this.state===Ar&&(i&&i.eventType&G?this.manager.emit(this.options.event+"up",i):(this._input.timeStamp=jo(),this.manager.emit(this.options.event,this._input)))},r}(ze),Vp={domEvents:!1,touchAction:qp,enable:!0,inputTarget:null,inputClass:null,cssProps:{userSelect:"none",touchSelect:"none",touchCallout:"none",contentZooming:"none",userDrag:"none",tapHighlightColor:"rgba(0,0,0,0)"}},Hp=[[Gp,{enable:!1}],[Up,{enable:!1},["rotate"]],[Kp,{direction:br}],[Go,{direction:br},["swipe"]],[Uo],[Uo,{event:"doubletap",taps:2},["tap"]],[Wp]],rq=1,zp=2;function Yp(e,r){var t=e.element;if(t.style){var n;wr(e.options.cssProps,function(i,a){n=mt(t.style,a),r?(e.oldCssProps[n]=t.style[n],t.style[n]=i):t.style[n]=e.oldCssProps[n]||""}),r||(e.oldCssProps={})}}function eq(e,r){var t=document.createEvent("Event");t.initEvent(e,!0,!0),t.gesture=r,r.target.dispatchEvent(t)}var Xp=function(){function e(t,n){var i=this;this.options=Gr({},Vp,n||{}),this.options.inputTarget=this.options.inputTarget||t,this.handlers={},this.session={},this.recognizers=[],this.oldCssProps={},this.element=t,this.input=JE(this),this.touchAction=new Pp(this,this.options.touchAction),Yp(this,!0),wr(this.options.recognizers,function(a){var o=i.add(new a[0](a[1]));a[2]&&o.recognizeWith(a[2]),a[3]&&o.requireFailure(a[3])},this)}var r=e.prototype;return r.set=function(n){return Gr(this.options,n),n.touchAction&&this.touchAction.update(),n.inputTarget&&(this.input.destroy(),this.input.target=n.inputTarget,this.input.init()),this},r.stop=function(n){this.session.stopped=n?zp:rq},r.recognize=function(n){var i=this.session;if(!i.stopped){this.touchAction.preventDefaults(n);var a,o=this.recognizers,s=i.curRecognizer;(!s||s&&s.state&Ar)&&(i.curRecognizer=null,s=null);for(var u=0;u<o.length;)a=o[u],i.stopped!==zp&&(!s||a===s||a.canRecognizeWith(s))?a.recognize(n):a.reset(),!s&&a.state&(lr|Ee|Lr)&&(i.curRecognizer=a,s=a),u++}},r.get=function(n){if(n instanceof ze)return n;for(var i=this.recognizers,a=0;a<i.length;a++)if(i[a].options.event===n)return i[a];return null},r.add=function(n){if(Se(n,"add",this))return this;var i=this.get(n.options.event);return i&&this.remove(i),this.recognizers.push(n),n.manager=this,this.touchAction.update(),n},r.remove=function(n){if(Se(n,"remove",this))return this;var i=this.get(n);if(n){var a=this.recognizers,o=Xr(a,i);o!==-1&&(a.splice(o,1),this.touchAction.update())}return this},r.on=function(n,i){if(n===void 0||i===void 0)return this;var a=this.handlers;return wr(Ue(n),function(o){a[o]=a[o]||[],a[o].push(i)}),this},r.off=function(n,i){if(n===void 0)return this;var a=this.handlers;return wr(Ue(n),function(o){i?a[o]&&a[o].splice(Xr(a[o],i),1):delete a[o]}),this},r.emit=function(n,i){this.options.domEvents&&eq(n,i);var a=this.handlers[n]&&this.handlers[n].slice();if(!(!a||!a.length)){i.type=n,i.preventDefault=function(){i.srcEvent.preventDefault()};for(var o=0;o<a.length;)a[o](i),o++}},r.destroy=function(){this.element&&Yp(this,!1),this.handlers={},this.session={},this.input.destroy(),this.element=null},e}(),tq={touchstart:er,touchmove:Hr,touchend:G,touchcancel:ir},nq="touchstart",iq="touchstart touchmove touchend touchcancel",aq=function(e){vr(r,e);function r(){var n,i=r.prototype;return i.evTarget=nq,i.evWin=iq,n=e.apply(this,arguments)||this,n.started=!1,n}var t=r.prototype;return t.handler=function(i){var a=tq[i.type];if(a===er&&(this.started=!0),!!this.started){var o=oq.call(this,i,a);a&(G|ir)&&o[0].length-o[1].length===0&&(this.started=!1),this.callback(this.manager,a,{pointers:o[0],changedPointers:o[1],pointerType:Le,srcEvent:i})}},r}(be);function oq(e,r){var t=Ve(e.touches),n=Ve(e.changedTouches);return r&(G|ir)&&(t=Bo(t.concat(n),"identifier",!0)),[t,n]}function Jp(e,r,t){var n="DEPRECATED METHOD: "+r+`
`+t+` AT 
`;return function(){var i=new Error("get-stack-trace"),a=i&&i.stack?i.stack.replace(/^[^\(]+?[\n$]/gm,"").replace(/^\s+at\s+/gm,"").replace(/^Object.<anonymous>\s*\(/gm,"{anonymous}()@"):"Unknown Stack Trace",o=window.console&&(window.console.warn||window.console.log);return o&&o.call(window.console,n,a),e.apply(this,arguments)}}var Zp=Jp(function(e,r,t){for(var n=Object.keys(r),i=0;i<n.length;)(!t||t&&e[n[i]]===void 0)&&(e[n[i]]=r[n[i]]),i++;return e},"extend","Use `assign`."),sq=Jp(function(e,r){return Zp(e,r,!0)},"merge","Use `assign`.");function uq(e,r,t){var n=r.prototype,i;i=e.prototype=Object.create(n),i.constructor=e,i._super=n,t&&Gr(i,t)}function Qp(e,r){return function(){return e.apply(r,arguments)}}var cq=function(){var e=function(t,n){return n===void 0&&(n={}),new Xp(t,pr({recognizers:Hp.concat()},n))};return e.VERSION="2.0.17-rc",e.DIRECTION_ALL=Rp,e.DIRECTION_DOWN=_e,e.DIRECTION_LEFT=Be,e.DIRECTION_RIGHT=ke,e.DIRECTION_UP=Ke,e.DIRECTION_HORIZONTAL=br,e.DIRECTION_VERTICAL=zr,e.DIRECTION_NONE=_t,e.DIRECTION_DOWN=_e,e.INPUT_START=er,e.INPUT_MOVE=Hr,e.INPUT_END=G,e.INPUT_CANCEL=ir,e.STATE_POSSIBLE=qt,e.STATE_BEGAN=lr,e.STATE_CHANGED=Ee,e.STATE_ENDED=Lr,e.STATE_RECOGNIZED=Ar,e.STATE_CANCELLED=He,e.STATE_FAILED=Sr,e.Manager=Xp,e.Input=be,e.TouchAction=Pp,e.TouchInput=ko,e.MouseInput=Ko,e.PointerEventInput=Mp,e.TouchMouseInput=Lp,e.SingleTouchInput=aq,e.Recognizer=ze,e.AttrRecognizer=qe,e.Tap=Uo,e.Pan=Go,e.Swipe=Kp,e.Pinch=Up,e.Rotate=Gp,e.Press=Wp,e.on=Ge,e.off=We,e.each=wr,e.merge=sq,e.extend=Zp,e.bindFn=Qp,e.assign=Gr,e.inherit=uq,e.bindFn=Qp,e.prefixed=mt,e.toArray=Ve,e.inArray=Xr,e.uniqueArray=Bo,e.splitStr=Ue,e.boolOrFn=St,e.hasParent=Fo,e.addEventListeners=Ge,e.removeEventListeners=We,e.defaults=Gr({},Vp,{preset:Hp}),e}();const Wo=Xb("DELETE");function fq(e){for(var r=arguments.length,t=new Array(r>1?r-1:0),n=1;n<r;n++)t[n-1]=arguments[n];return ry({},e,...t)}function ry(){const e=Ot(...arguments);return ty(e),e}function Ot(){for(var e=arguments.length,r=new Array(e),t=0;t<e;t++)r[t]=arguments[t];if(r.length<2)return r[0];if(r.length>2)return Ot(ry(r[0],r[1]),...nS(r).call(r,2));const n=r[0],i=r[1];if(n instanceof Date&&i instanceof Date)return n.setTime(i.getTime()),n;for(const a of id(i))Object.prototype.propertyIsEnumerable.call(i,a)&&(i[a]===Wo?delete n[a]:n[a]!==null&&i[a]!==null&&typeof n[a]=="object"&&typeof i[a]=="object"&&!dr(n[a])&&!dr(i[a])?n[a]=Ot(n[a],i[a]):n[a]=ey(i[a]));return n}function ey(e){return dr(e)?sr(e).call(e,r=>ey(r)):typeof e=="object"&&e!==null?e instanceof Date?new Date(e.getTime()):Ot({},e):e}function ty(e){for(const r of Ya(e))e[r]===Wo?delete e[r]:typeof e[r]=="object"&&e[r]!==null&&ty(e[r])}function vq(){const e=()=>{};return{on:e,off:e,destroy:e,emit:e,get(){return{set:e}}}}const lq=typeof window<"u"?window.Hammer||cq:function(){return vq()};function $r(e){var r;this._cleanupQueue=[],this.active=!1,this._dom={container:e,overlay:document.createElement("div")},this._dom.overlay.classList.add("vis-overlay"),this._dom.container.appendChild(this._dom.overlay),this._cleanupQueue.push(()=>{this._dom.overlay.parentNode.removeChild(this._dom.overlay)});const t=lq(this._dom.overlay);t.on("tap",Ur(r=this._onTapOverlay).call(r,this)),this._cleanupQueue.push(()=>{t.destroy()});const n=["tap","doubletap","press","pinch","pan","panstart","panmove","panend"];Fr(n).call(n,i=>{t.on(i,a=>{a.srcEvent.stopPropagation()})}),document&&document.body&&(this._onClick=i=>{hq(i.target,e)||this.deactivate()},document.body.addEventListener("click",this._onClick),this._cleanupQueue.push(()=>{document.body.removeEventListener("click",this._onClick)})),this._escListener=i=>{("key"in i?i.key==="Escape":i.keyCode===27)&&this.deactivate()}}qE($r.prototype),$r.current=null,$r.prototype.destroy=function(){this.deactivate();for(const t of DS(e=Nd(r=this._cleanupQueue).call(r,0)).call(e)){var e,r;t()}},$r.prototype.activate=function(){$r.current&&$r.current.deactivate(),$r.current=this,this.active=!0,this._dom.overlay.style.display="none",this._dom.container.classList.add("vis-active"),this.emit("change"),this.emit("activate"),document.body.addEventListener("keydown",this._escListener)},$r.prototype.deactivate=function(){this.active=!1,this._dom.overlay.style.display="block",this._dom.container.classList.remove("vis-active"),document.body.removeEventListener("keydown",this._escListener),this.emit("change"),this.emit("deactivate")},$r.prototype._onTapOverlay=function(e){this.activate(),e.srcEvent.stopPropagation()};function hq(e,r){for(;e;){if(e===r)return!0;e=e.parentNode}return!1}var Vo,ny;function dq(){if(ny)return Vo;ny=1,tv();var e=V();return Vo=e.Object.getOwnPropertySymbols,Vo}var Ho,iy;function pq(){if(iy)return Ho;iy=1;var e=dq();return Ho=e,Ho}var zo,ay;function yq(){return ay||(ay=1,zo=pq()),zo}var mq=yq(),oy=$(mq),Yo={exports:{}},sy={},uy;function gq(){if(uy)return sy;uy=1;var e=A(),r=j(),t=mr(),n=at().f,i=U(),a=!i||r(function(){n(1)});return e({target:"Object",stat:!0,forced:a,sham:!i},{getOwnPropertyDescriptor:function(s,u){return n(t(s),u)}}),sy}var cy;function _q(){if(cy)return Yo.exports;cy=1,gq();var e=V(),r=e.Object,t=Yo.exports=function(i,a){return r.getOwnPropertyDescriptor(i,a)};return r.getOwnPropertyDescriptor.sham&&(t.sham=!0),Yo.exports}var Xo,fy;function bq(){if(fy)return Xo;fy=1;var e=_q();return Xo=e,Xo}var Jo,vy;function Sq(){return vy||(vy=1,Jo=bq()),Jo}var Eq=Sq(),ly=$(Eq),hy={},dy;function qq(){if(dy)return hy;dy=1;var e=A(),r=U(),t=Qh(),n=mr(),i=at(),a=ot();return e({target:"Object",stat:!0,sham:!r},{getOwnPropertyDescriptors:function(s){for(var u=n(s),c=i.f,f=t(u),v={},h=0,l,d;f.length>h;)d=c(u,l=f[h++]),d!==void 0&&a(v,l,d);return v}}),hy}var Zo,py;function Iq(){if(py)return Zo;py=1,qq();var e=V();return Zo=e.Object.getOwnPropertyDescriptors,Zo}var Qo,yy;function Oq(){if(yy)return Qo;yy=1;var e=Iq();return Qo=e,Qo}var rs,my;function Rq(){return my||(my=1,rs=Oq()),rs}var Tq=Rq(),gy=$(Tq),es={exports:{}},_y={},by;function Pq(){if(by)return _y;by=1;var e=A(),r=U(),t=ai().f;return e({target:"Object",stat:!0,forced:Object.defineProperties!==t,sham:!r},{defineProperties:t}),_y}var Sy;function wq(){if(Sy)return es.exports;Sy=1,Pq();var e=V(),r=e.Object,t=es.exports=function(i,a){return r.defineProperties(i,a)};return r.defineProperties.sham&&(t.sham=!0),es.exports}var ts,Ey;function Aq(){if(Ey)return ts;Ey=1;var e=wq();return ts=e,ts}var ns,qy;function $q(){return qy||(qy=1,ns=Aq()),ns}var Dq=$q(),Cq=$(Dq),is,Iy;function xq(){return Iy||(Iy=1,is=Kc()),is}var jq=xq(),Oy=$(jq),Ry={},Ty={},as={exports:{}},os,Py;function Mq(){if(Py)return os;Py=1;var e=j();return os=e(function(){if(typeof ArrayBuffer=="function"){var r=new ArrayBuffer(8);Object.isExtensible(r)&&Object.defineProperty(r,"a",{value:8})}}),os}var ss,wy;function Nq(){if(wy)return ss;wy=1;var e=j(),r=Q(),t=Rr(),n=Mq(),i=Object.isExtensible,a=e(function(){});return ss=a||n?function(s){return!r(s)||n&&t(s)==="ArrayBuffer"?!1:i?i(s):!0}:i,ss}var us,Ay;function Fq(){if(Ay)return us;Ay=1;var e=j();return us=!e(function(){return Object.isExtensible(Object.preventExtensions({}))}),us}var $y;function Dy(){if($y)return as.exports;$y=1;var e=A(),r=N(),t=De(),n=Q(),i=Y(),a=cr().f,o=ft(),s=wf(),u=Nq(),c=it(),f=Fq(),v=!1,h=c("meta"),l=0,d=function(_){a(_,h,{value:{objectID:"O"+l++,weakData:{}}})},p=function(_,E){if(!n(_))return typeof _=="symbol"?_:(typeof _=="string"?"S":"P")+_;if(!i(_,h)){if(!u(_))return"F";if(!E)return"E";d(_)}return _[h].objectID},S=function(_,E){if(!i(_,h)){if(!u(_))return!0;if(!E)return!1;d(_)}return _[h].weakData},g=function(_){return f&&v&&u(_)&&!i(_,h)&&d(_),_},m=function(){T.enable=function(){},v=!0;var _=o.f,E=r([].splice),I={};I[h]=1,_(I).length&&(o.f=function(O){for(var y=_(O),b=0,q=y.length;b<q;b++)if(y[b]===h){E(y,b,1);break}return y},e({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:s.f}))},T=as.exports={enable:m,fastKey:p,getWeakData:S,onFreeze:g};return t[h]=!0,as.exports}var cs,Cy;function Lq(){if(Cy)return cs;Cy=1;var e=X(),r=me(),t=e("iterator"),n=Array.prototype;return cs=function(i){return i!==void 0&&(r.Array===i||n[t]===i)},cs}var fs,xy;function jy(){if(xy)return fs;xy=1;var e=xr(),r=on(),t=Te(),n=me(),i=X(),a=i("iterator");return fs=function(o){if(!t(o))return r(o,a)||r(o,"@@iterator")||n[e(o)]},fs}var vs,My;function Ny(){if(My)return vs;My=1;var e=nr(),r=gr(),t=Tr(),n=fe(),i=jy(),a=TypeError;return vs=function(o,s){var u=arguments.length<2?i(o):s;if(r(u))return t(e(u,o));throw new a(n(o)+" is not iterable")},vs}var ls,Fy;function hs(){if(Fy)return ls;Fy=1;var e=nr(),r=Tr(),t=on();return ls=function(n,i,a){var o,s;r(n);try{if(o=t(n,"return"),!o){if(i==="throw")throw a;return a}o=e(o,n)}catch(u){s=!0,o=u}if(i==="throw")throw a;if(s)throw o;return r(o),a},ls}var ds,Ly;function ps(){if(Ly)return ds;Ly=1;var e=Ae(),r=nr(),t=Tr(),n=fe(),i=Lq(),a=_r(),o=H(),s=Ny(),u=jy(),c=hs(),f=TypeError,v=function(l,d){this.stopped=l,this.result=d},h=v.prototype;return ds=function(l,d,p){var S=p&&p.that,g=!!(p&&p.AS_ENTRIES),m=!!(p&&p.IS_RECORD),T=!!(p&&p.IS_ITERATOR),_=!!(p&&p.INTERRUPTED),E=e(d,S),I,O,y,b,q,R,P,w=function(W){return I&&c(I,"normal"),new v(!0,W)},M=function(W){return g?(t(W),_?E(W[0],W[1],w):E(W[0],W[1])):_?E(W,w):E(W)};if(m)I=l.iterator;else if(T)I=l;else{if(O=u(l),!O)throw new f(n(l)+" is not iterable");if(i(O)){for(y=0,b=a(l);b>y;y++)if(q=M(l[y]),q&&o(h,q))return q;return new v(!1)}I=s(l,O)}for(R=m?l.next:I.next;!(P=r(R,I)).done;){try{q=M(P.value)}catch(W){c(I,"throw",W)}if(typeof q=="object"&&q&&o(h,q))return q}return new v(!1)},ds}var ys,By;function ky(){if(By)return ys;By=1;var e=H(),r=TypeError;return ys=function(t,n){if(e(n,t))return t;throw new r("Incorrect invocation")},ys}var ms,Ky;function Uy(){if(Ky)return ms;Ky=1;var e=A(),r=K(),t=Dy(),n=j(),i=he(),a=ps(),o=ky(),s=z(),u=Q(),c=Te(),f=Kr(),v=cr().f,h=ye().forEach,l=U(),d=je(),p=d.set,S=d.getterFor;return ms=function(g,m,T){var _=g.indexOf("Map")!==-1,E=g.indexOf("Weak")!==-1,I=_?"set":"add",O=r[g],y=O&&O.prototype,b={},q;if(!l||!s(O)||!(E||y.forEach&&!n(function(){new O().entries().next()})))q=T.getConstructor(m,g,_,I),t.enable();else{q=m(function(w,M){p(o(w,R),{type:g,collection:new O}),c(M)||a(M,w[I],{that:w,AS_ENTRIES:_})});var R=q.prototype,P=S(g);h(["add","clear","delete","forEach","get","has","set","keys","values","entries"],function(w){var M=w==="add"||w==="set";w in y&&!(E&&w==="clear")&&i(R,w,function(W,ie){var tr=P(this).collection;if(!M&&E&&!u(W))return w==="get"?void 0:!1;var Er=tr[w](W===0?0:W,ie);return M?this:Er})}),E||v(R,"size",{configurable:!0,get:function(){return P(this).collection.size}})}return f(q,g,!1,!0),b[g]=q,e({global:!0,forced:!0},b),E||T.setStrong(q,g,_),q},ms}var gs,Gy;function Bq(){if(Gy)return gs;Gy=1;var e=xe();return gs=function(r,t,n){for(var i in t)n&&n.unsafe&&r[i]?r[i]=t[i]:e(r,i,t[i],n);return r},gs}var _s,Wy;function kq(){if(Wy)return _s;Wy=1;var e=or(),r=pi(),t=X(),n=U(),i=t("species");return _s=function(a){var o=e(a);n&&o&&!o[i]&&r(o,i,{configurable:!0,get:function(){return this}})},_s}var bs,Vy;function Hy(){if(Vy)return bs;Vy=1;var e=Ce(),r=pi(),t=Bq(),n=Ae(),i=ky(),a=Te(),o=ps(),s=Li(),u=ki(),c=kq(),f=U(),v=Dy().fastKey,h=je(),l=h.set,d=h.getterFor;return bs={getConstructor:function(p,S,g,m){var T=p(function(y,b){i(y,_),l(y,{type:S,index:e(null),first:null,last:null,size:0}),f||(y.size=0),a(b)||o(b,y[m],{that:y,AS_ENTRIES:g})}),_=T.prototype,E=d(S),I=function(y,b,q){var R=E(y),P=O(y,b),w,M;return P?P.value=q:(R.last=P={index:M=v(b,!0),key:b,value:q,previous:w=R.last,next:null,removed:!1},R.first||(R.first=P),w&&(w.next=P),f?R.size++:y.size++,M!=="F"&&(R.index[M]=P)),y},O=function(y,b){var q=E(y),R=v(b),P;if(R!=="F")return q.index[R];for(P=q.first;P;P=P.next)if(P.key===b)return P};return t(_,{clear:function(){for(var b=this,q=E(b),R=q.first;R;)R.removed=!0,R.previous&&(R.previous=R.previous.next=null),R=R.next;q.first=q.last=null,q.index=e(null),f?q.size=0:b.size=0},delete:function(y){var b=this,q=E(b),R=O(b,y);if(R){var P=R.next,w=R.previous;delete q.index[R.index],R.removed=!0,w&&(w.next=P),P&&(P.previous=w),q.first===R&&(q.first=P),q.last===R&&(q.last=w),f?q.size--:b.size--}return!!R},forEach:function(b){for(var q=E(this),R=n(b,arguments.length>1?arguments[1]:void 0),P;P=P?P.next:q.first;)for(R(P.value,P.key,this);P&&P.removed;)P=P.previous},has:function(b){return!!O(this,b)}}),t(_,g?{get:function(b){var q=O(this,b);return q&&q.value},set:function(b,q){return I(this,b===0?0:b,q)}}:{add:function(b){return I(this,b=b===0?0:b,b)}}),f&&r(_,"size",{configurable:!0,get:function(){return E(this).size}}),T},setStrong:function(p,S,g){var m=S+" Iterator",T=d(S),_=d(m);s(p,S,function(E,I){l(this,{type:m,target:E,state:T(E),kind:I,last:null})},function(){for(var E=_(this),I=E.kind,O=E.last;O&&O.removed;)O=O.previous;return!E.target||!(E.last=O=O?O.next:E.state.first)?(E.target=null,u(void 0,!0)):u(I==="keys"?O.key:I==="values"?O.value:[O.key,O.value],!1)},g?"entries":"values",!g,!0),c(S)}},bs}var zy;function Kq(){if(zy)return Ty;zy=1;var e=Uy(),r=Hy();return e("Map",function(t){return function(){return t(this,arguments.length?arguments[0]:void 0)}},r),Ty}var Yy;function Uq(){return Yy||(Yy=1,Kq()),Ry}var Xy={},Ss,Jy;function Zy(){return Jy||(Jy=1,Ss=function(e,r){return r===1?function(t,n){return t[e](n)}:function(t,n,i){return t[e](n,i)}}),Ss}var Es,Qy;function Gq(){if(Qy)return Es;Qy=1;var e=or(),r=Zy(),t=e("Map");return Es={Map:t,set:r("set",2),get:r("get",1),has:r("has",1),remove:r("delete",1),proto:t.prototype},Es}var rm;function Wq(){if(rm)return Xy;rm=1;var e=A(),r=N(),t=gr(),n=kr(),i=ps(),a=Gq(),o=ve(),s=j(),u=a.Map,c=a.has,f=a.get,v=a.set,h=r([].push),l=o||s(function(){return u.groupBy("ab",function(d){return d}).get("a").length!==1});return e({target:"Map",stat:!0,forced:o||l},{groupBy:function(p,S){n(p),t(S);var g=new u,m=0;return i(p,function(T){var _=S(T,m++);c(g,_)?h(f(g,_),T):v(g,_,[T])}),g}}),Xy}var qs,em;function Vq(){if(em)return qs;em=1,Mr(),Uq(),Wq(),dt();var e=V();return qs=e.Map,qs}var Is,tm;function Hq(){if(tm)return Is;tm=1;var e=Vq();return Nr(),Is=e,Is}var Os,nm;function zq(){return nm||(nm=1,Os=Hq()),Os}var Yq=zq(),im=$(Yq),am={},om;function Xq(){if(om)return am;om=1;var e=A(),r=ye().some,t=pt(),n=t("some");return e({target:"Array",proto:!0,forced:!n},{some:function(a){return r(this,a,arguments.length>1?arguments[1]:void 0)}}),am}var Rs,sm;function Jq(){if(sm)return Rs;sm=1,Xq();var e=rr();return Rs=e("Array","some"),Rs}var Ts,um;function Zq(){if(um)return Ts;um=1;var e=H(),r=Jq(),t=Array.prototype;return Ts=function(n){var i=n.some;return n===t||e(t,n)&&i===t.some?r:i},Ts}var Ps,cm;function Qq(){if(cm)return Ps;cm=1;var e=Zq();return Ps=e,Ps}var ws,fm;function rI(){return fm||(fm=1,ws=Qq()),ws}var eI=rI(),tI=$(eI),As,vm;function nI(){if(vm)return As;vm=1,Mr();var e=rr();return As=e("Array","keys"),As}var $s,lm;function iI(){if(lm)return $s;lm=1;var e=nI();return $s=e,$s}var Ds,hm;function aI(){if(hm)return Ds;hm=1,Nr();var e=xr(),r=Y(),t=H(),n=iI(),i=Array.prototype,a={DOMTokenList:!0,NodeList:!0};return Ds=function(o){var s=o.keys;return o===i||t(i,o)&&s===i.keys||r(a,e(o))?n:s},Ds}var Cs,dm;function oI(){return dm||(dm=1,Cs=aI()),Cs}var sI=oI(),Jr=$(sI),pm={},xs,ym;function uI(){if(ym)return xs;ym=1;var e=pe(),r=Math.floor,t=function(n,i){var a=n.length;if(a<8)for(var o=1,s,u;o<a;){for(u=o,s=n[o];u&&i(n[u-1],s)>0;)n[u]=n[--u];u!==o++&&(n[u]=s)}else for(var c=r(a/2),f=t(e(n,0,c),i),v=t(e(n,c),i),h=f.length,l=v.length,d=0,p=0;d<h||p<l;)n[d+p]=d<h&&p<l?i(f[d],v[p])<=0?f[d++]:v[p++]:d<h?f[d++]:v[p++];return n};return xs=t,xs}var js,mm;function cI(){if(mm)return js;mm=1;var e=ue(),r=e.match(/firefox\/(\d+)/i);return js=!!r&&+r[1],js}var Ms,gm;function fI(){if(gm)return Ms;gm=1;var e=ue();return Ms=/MSIE|Trident/.test(e),Ms}var Ns,_m;function vI(){if(_m)return Ns;_m=1;var e=ue(),r=e.match(/AppleWebKit\/(\d+)\./);return Ns=!!r&&+r[1],Ns}var bm;function lI(){if(bm)return pm;bm=1;var e=A(),r=N(),t=gr(),n=ur(),i=_r(),a=$d(),o=jr(),s=j(),u=uI(),c=pt(),f=cI(),v=fI(),h=Pe(),l=vI(),d=[],p=r(d.sort),S=r(d.push),g=s(function(){d.sort(void 0)}),m=s(function(){d.sort(null)}),T=c("sort"),_=!s(function(){if(h)return h<70;if(!(f&&f>3)){if(v)return!0;if(l)return l<603;var O="",y,b,q,R;for(y=65;y<76;y++){switch(b=String.fromCharCode(y),y){case 66:case 69:case 70:case 72:q=3;break;case 68:case 71:q=4;break;default:q=2}for(R=0;R<47;R++)d.push({k:b+R,v:q})}for(d.sort(function(P,w){return w.v-P.v}),R=0;R<d.length;R++)b=d[R].k.charAt(0),O.charAt(O.length-1)!==b&&(O+=b);return O!=="DGBEFHACIJK"}}),E=g||!m||!T||!_,I=function(O){return function(y,b){return b===void 0?-1:y===void 0?1:O!==void 0?+O(y,b)||0:o(y)>o(b)?1:-1}};return e({target:"Array",proto:!0,forced:E},{sort:function(y){y!==void 0&&t(y);var b=n(this);if(_)return y===void 0?p(b):p(b,y);var q=[],R=i(b),P,w;for(w=0;w<R;w++)w in b&&S(q,b[w]);for(u(q,I(y)),P=i(q),w=0;w<P;)b[w]=q[w++];for(;w<R;)a(b,w++);return b}}),pm}var Fs,Sm;function hI(){if(Sm)return Fs;Sm=1,lI();var e=rr();return Fs=e("Array","sort"),Fs}var Ls,Em;function dI(){if(Em)return Ls;Em=1;var e=H(),r=hI(),t=Array.prototype;return Ls=function(n){var i=n.sort;return n===t||e(t,n)&&i===t.sort?r:i},Ls}var Bs,qm;function pI(){if(qm)return Bs;qm=1;var e=dI();return Bs=e,Bs}var ks,Im;function yI(){return Im||(Im=1,ks=pI()),ks}var mI=yI(),Ks=$(mI),Us,Om;function gI(){if(Om)return Us;Om=1,Mr();var e=rr();return Us=e("Array","values"),Us}var Gs,Rm;function _I(){if(Rm)return Gs;Rm=1;var e=gI();return Gs=e,Gs}var Ws,Tm;function bI(){if(Tm)return Ws;Tm=1,Nr();var e=xr(),r=Y(),t=H(),n=_I(),i=Array.prototype,a={DOMTokenList:!0,NodeList:!0};return Ws=function(o){var s=o.values;return o===i||t(i,o)&&s===i.values||r(a,e(o))?n:s},Ws}var Vs,Pm;function SI(){return Pm||(Pm=1,Vs=bI()),Vs}var EI=SI(),wm=$(EI),Hs,Am;function qI(){return Am||(Am=1,Hs=zl()),Hs}var II=qI(),Zr=$(II),zs,$m;function OI(){if($m)return zs;$m=1,Mr();var e=rr();return zs=e("Array","entries"),zs}var Ys,Dm;function RI(){if(Dm)return Ys;Dm=1;var e=OI();return Ys=e,Ys}var Xs,Cm;function TI(){if(Cm)return Xs;Cm=1,Nr();var e=xr(),r=Y(),t=H(),n=RI(),i=Array.prototype,a={DOMTokenList:!0,NodeList:!0};return Xs=function(o){var s=o.entries;return o===i||t(i,o)&&s===i.entries||r(a,e(o))?n:s},Xs}var Js,xm;function PI(){return xm||(xm=1,Js=TI()),Js}var wI=PI(),AI=$(wI);const Z=[];for(let e=0;e<256;++e)Z.push((e+256).toString(16).slice(1));function $I(e,r=0){return(Z[e[r+0]]+Z[e[r+1]]+Z[e[r+2]]+Z[e[r+3]]+"-"+Z[e[r+4]]+Z[e[r+5]]+"-"+Z[e[r+6]]+Z[e[r+7]]+"-"+Z[e[r+8]]+Z[e[r+9]]+"-"+Z[e[r+10]]+Z[e[r+11]]+Z[e[r+12]]+Z[e[r+13]]+Z[e[r+14]]+Z[e[r+15]]).toLowerCase()}let Zs;const DI=new Uint8Array(16);function CI(){if(!Zs){if(typeof crypto>"u"||!crypto.getRandomValues)throw new Error("crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported");Zs=crypto.getRandomValues.bind(crypto)}return Zs(DI)}var jm={randomUUID:typeof crypto<"u"&&crypto.randomUUID&&crypto.randomUUID.bind(crypto)};function xI(e,r,t){e=e||{};const n=e.random??e.rng?.()??CI();if(n.length<16)throw new Error("Random bytes length must be >= 16");return n[6]=n[6]&15|64,n[8]=n[8]&63|128,$I(n)}function jI(e,r,t){return jm.randomUUID&&!e?jm.randomUUID():xI(e)}function Qs(e){return typeof e=="string"||typeof e=="number"}class Rt{constructor(r){fr(this,"_queue",[]),fr(this,"_timeout",null),fr(this,"_extended",null),this.delay=null,this.max=1/0,this.setOptions(r)}setOptions(r){r&&typeof r.delay<"u"&&(this.delay=r.delay),r&&typeof r.max<"u"&&(this.max=r.max),this._flushIfNeeded()}static extend(r,t){const n=new Rt(t);if(r.flush!==void 0)throw new Error("Target object already has a property flush");r.flush=()=>{n.flush()};const i=[{name:"flush",original:void 0}];if(t&&t.replace)for(let a=0;a<t.replace.length;a++){const o=t.replace[a];i.push({name:o,original:r[o]}),n.replace(r,o)}return n._extended={object:r,methods:i},n}destroy(){if(this.flush(),this._extended){const r=this._extended.object,t=this._extended.methods;for(let n=0;n<t.length;n++){const i=t[n];i.original?r[i.name]=i.original:delete r[i.name]}this._extended=null}}replace(r,t){const n=this,i=r[t];if(!i)throw new Error("Method "+t+" undefined");r[t]=function(){for(var a=arguments.length,o=new Array(a),s=0;s<a;s++)o[s]=arguments[s];n.queue({args:o,fn:i,context:this})}}queue(r){typeof r=="function"?this._queue.push({fn:r}):this._queue.push(r),this._flushIfNeeded()}_flushIfNeeded(){this._queue.length>this.max&&this.flush(),this._timeout!=null&&(clearTimeout(this._timeout),this._timeout=null),this.queue.length>0&&typeof this.delay=="number"&&(this._timeout=bE(()=>{this.flush()},this.delay))}flush(){var r,t;Fr(r=Nd(t=this._queue).call(t,0)).call(r,n=>{n.fn.apply(n.context||n.fn,n.args||[])})}}class Ye{constructor(){fr(this,"_subscribers",{"*":[],add:[],remove:[],update:[]}),fr(this,"subscribe",Ye.prototype.on),fr(this,"unsubscribe",Ye.prototype.off)}_trigger(r,t,n){var i;if(r==="*")throw new Error("Cannot trigger event *");Fr(i=[...this._subscribers[r],...this._subscribers["*"]]).call(i,a=>{a(r,t,n??null)})}on(r,t){typeof t=="function"&&this._subscribers[r].push(t)}off(r,t){var n;this._subscribers[r]=J(n=this._subscribers[r]).call(n,i=>i!==t)}}var Mm={},Nm={},Fm;function MI(){if(Fm)return Nm;Fm=1;var e=Uy(),r=Hy();return e("Set",function(t){return function(){return t(this,arguments.length?arguments[0]:void 0)}},r),Nm}var Lm;function NI(){return Lm||(Lm=1,MI()),Mm}var Bm={},ru,km;function Qr(){if(km)return ru;km=1;var e=fe(),r=TypeError;return ru=function(t){if(typeof t=="object"&&"size"in t&&"has"in t&&"add"in t&&"delete"in t&&"keys"in t)return t;throw new r(e(t)+" is not a set")},ru}var eu,Km;function re(){if(Km)return eu;Km=1;var e=or(),r=Zy(),t=e("Set"),n=t.prototype;return eu={Set:t,add:r("add",1),has:r("has",1),remove:r("delete",1),proto:n},eu}var tu,Um;function ee(){if(Um)return tu;Um=1;var e=nr();return tu=function(r,t,n){for(var i=n?r:r.iterator,a=r.next,o,s;!(o=e(a,i)).done;)if(s=t(o.value),s!==void 0)return s},tu}var nu,Gm;function Xe(){if(Gm)return nu;Gm=1;var e=ee();return nu=function(r,t,n){return n?e(r.keys(),t,!0):r.forEach(t)},nu}var iu,Wm;function au(){if(Wm)return iu;Wm=1;var e=re(),r=Xe(),t=e.Set,n=e.add;return iu=function(i){var a=new t;return r(i,function(o){n(a,o)}),a},iu}var ou,Vm;function Je(){return Vm||(Vm=1,ou=function(e){return e.size}),ou}var su,Hm;function FI(){return Hm||(Hm=1,su=function(e){return{iterator:e,next:e.next,done:!1}}),su}var uu,zm;function te(){if(zm)return uu;zm=1;var e=gr(),r=Tr(),t=nr(),n=de(),i=FI(),a="Invalid size",o=RangeError,s=TypeError,u=Math.max,c=function(f,v){this.set=f,this.size=u(v,0),this.has=e(f.has),this.keys=e(f.keys)};return c.prototype={getIterator:function(){return i(r(t(this.keys,this.set)))},includes:function(f){return t(this.has,this.set,f)}},uu=function(f){r(f);var v=+f.size;if(v!==v)throw new s(a);var h=n(v);if(h<0)throw new o(a);return new c(f,h)},uu}var cu,Ym;function LI(){if(Ym)return cu;Ym=1;var e=Qr(),r=re(),t=au(),n=Je(),i=te(),a=Xe(),o=ee(),s=r.has,u=r.remove;return cu=function(f){var v=e(this),h=i(f),l=t(v);return n(v)<=h.size?a(v,function(d){h.includes(d)&&u(l,d)}):o(h.getIterator(),function(d){s(l,d)&&u(l,d)}),l},cu}var fu,Xm;function ne(){return Xm||(Xm=1,fu=function(){return!1}),fu}var Jm;function BI(){if(Jm)return Bm;Jm=1;var e=A(),r=LI(),t=j(),n=ne(),i=!n("difference",function(o){return o.size===0}),a=i||t(function(){var o={size:1,has:function(){return!0},keys:function(){var u=0;return{next:function(){var c=u++>1;return s.has(1)&&s.clear(),{done:c,value:2}}}}},s=new Set([1,2,3,4]);return s.difference(o).size!==3});return e({target:"Set",proto:!0,real:!0,forced:a},{difference:r}),Bm}var Zm={},vu,Qm;function kI(){if(Qm)return vu;Qm=1;var e=Qr(),r=re(),t=Je(),n=te(),i=Xe(),a=ee(),o=r.Set,s=r.add,u=r.has;return vu=function(f){var v=e(this),h=n(f),l=new o;return t(v)>h.size?a(h.getIterator(),function(d){u(v,d)&&s(l,d)}):i(v,function(d){h.includes(d)&&s(l,d)}),l},vu}var rg;function KI(){if(rg)return Zm;rg=1;var e=A(),r=j(),t=kI(),n=ne(),i=!n("intersection",function(a){return a.size===2&&a.has(1)&&a.has(2)})||r(function(){return String(Array.from(new Set([1,2,3]).intersection(new Set([3,2]))))!=="3,2"});return e({target:"Set",proto:!0,real:!0,forced:i},{intersection:t}),Zm}var eg={},lu,tg;function UI(){if(tg)return lu;tg=1;var e=Qr(),r=re().has,t=Je(),n=te(),i=Xe(),a=ee(),o=hs();return lu=function(u){var c=e(this),f=n(u);if(t(c)<=f.size)return i(c,function(h){if(f.includes(h))return!1},!0)!==!1;var v=f.getIterator();return a(v,function(h){if(r(c,h))return o(v,"normal",!1)})!==!1},lu}var ng;function GI(){if(ng)return eg;ng=1;var e=A(),r=UI(),t=ne(),n=!t("isDisjointFrom",function(i){return!i});return e({target:"Set",proto:!0,real:!0,forced:n},{isDisjointFrom:r}),eg}var ig={},hu,ag;function WI(){if(ag)return hu;ag=1;var e=Qr(),r=Je(),t=Xe(),n=te();return hu=function(a){var o=e(this),s=n(a);return r(o)>s.size?!1:t(o,function(u){if(!s.includes(u))return!1},!0)!==!1},hu}var og;function VI(){if(og)return ig;og=1;var e=A(),r=WI(),t=ne(),n=!t("isSubsetOf",function(i){return i});return e({target:"Set",proto:!0,real:!0,forced:n},{isSubsetOf:r}),ig}var sg={},du,ug;function HI(){if(ug)return du;ug=1;var e=Qr(),r=re().has,t=Je(),n=te(),i=ee(),a=hs();return du=function(s){var u=e(this),c=n(s);if(t(u)<c.size)return!1;var f=c.getIterator();return i(f,function(v){if(!r(u,v))return a(f,"normal",!1)})!==!1},du}var cg;function zI(){if(cg)return sg;cg=1;var e=A(),r=HI(),t=ne(),n=!t("isSupersetOf",function(i){return!i});return e({target:"Set",proto:!0,real:!0,forced:n},{isSupersetOf:r}),sg}var fg={},pu,vg;function YI(){if(vg)return pu;vg=1;var e=Qr(),r=re(),t=au(),n=te(),i=ee(),a=r.add,o=r.has,s=r.remove;return pu=function(c){var f=e(this),v=n(c).getIterator(),h=t(f);return i(v,function(l){o(f,l)?s(h,l):a(h,l)}),h},pu}var yu,lg;function hg(){return lg||(lg=1,yu=function(e){try{var r=new Set,t={size:0,has:function(){return!0},keys:function(){return Object.defineProperty({},"next",{get:function(){return r.clear(),r.add(4),function(){return{done:!0}}}})}},n=r[e](t);return n.size===1&&n.values().next().value===4}catch{return!1}}),yu}var dg;function XI(){if(dg)return fg;dg=1;var e=A(),r=YI(),t=hg(),n=ne(),i=!n("symmetricDifference")||!t("symmetricDifference");return e({target:"Set",proto:!0,real:!0,forced:i},{symmetricDifference:r}),fg}var pg={},mu,yg;function JI(){if(yg)return mu;yg=1;var e=Qr(),r=re().add,t=au(),n=te(),i=ee();return mu=function(o){var s=e(this),u=n(o).getIterator(),c=t(s);return i(u,function(f){r(c,f)}),c},mu}var mg;function ZI(){if(mg)return pg;mg=1;var e=A(),r=JI(),t=hg(),n=ne(),i=!n("union")||!t("union");return e({target:"Set",proto:!0,real:!0,forced:i},{union:r}),pg}var gu,gg;function QI(){if(gg)return gu;gg=1,Mr(),NI(),BI(),KI(),GI(),VI(),zI(),XI(),ZI(),dt();var e=V();return gu=e.Set,gu}var _u,_g;function rO(){if(_g)return _u;_g=1;var e=QI();return Nr(),_u=e,_u}var bu,bg;function eO(){return bg||(bg=1,bu=rO()),bu}var tO=eO(),Tt=$(tO),Su,Sg;function nO(){if(Sg)return Su;Sg=1,Mr(),dt();var e=Ny();return Su=e,Su}var Eu,Eg;function iO(){if(Eg)return Eu;Eg=1;var e=nO();return Nr(),Eu=e,Eu}var qu,qg;function aO(){if(qg)return qu;qg=1;var e=iO();return qu=e,qu}var Iu,Ig;function oO(){if(Ig)return Iu;Ig=1;var e=aO();return Iu=e,Iu}var Ou,Og;function sO(){return Og||(Og=1,Ou=oO()),Ou}var Ru,Rg;function uO(){return Rg||(Rg=1,Ru=sO()),Ru}var cO=uO(),Tu=$(cO);class Br{constructor(r){this._pairs=r}*[Zr](){for(const[r,t]of this._pairs)yield[r,t]}*entries(){for(const[r,t]of this._pairs)yield[r,t]}*keys(){for(const[r]of this._pairs)yield r}*values(){for(const[,r]of this._pairs)yield r}toIdArray(){var r;return sr(r=[...this._pairs]).call(r,t=>t[0])}toItemArray(){var r;return sr(r=[...this._pairs]).call(r,t=>t[1])}toEntryArray(){return[...this._pairs]}toObjectMap(){const r=nE(null);for(const[t,n]of this._pairs)r[t]=n;return r}toMap(){return new im(this._pairs)}toIdSet(){return new Tt(this.toIdArray())}toItemSet(){return new Tt(this.toItemArray())}cache(){return new Br([...this._pairs])}distinct(r){const t=new Tt;for(const[n,i]of this._pairs)t.add(r(i,n));return t}filter(r){const t=this._pairs;return new Br({*[Zr](){for(const[n,i]of t)r(i,n)&&(yield[n,i])}})}forEach(r){for(const[t,n]of this._pairs)r(n,t)}map(r){const t=this._pairs;return new Br({*[Zr](){for(const[n,i]of t)yield[n,r(i,n)]}})}max(r){const t=Tu(this._pairs);let n=t.next();if(n.done)return null;let i=n.value[1],a=r(n.value[1],n.value[0]);for(;!(n=t.next()).done;){const[o,s]=n.value,u=r(s,o);u>a&&(a=u,i=s)}return i}min(r){const t=Tu(this._pairs);let n=t.next();if(n.done)return null;let i=n.value[1],a=r(n.value[1],n.value[0]);for(;!(n=t.next()).done;){const[o,s]=n.value,u=r(s,o);u<a&&(a=u,i=s)}return i}reduce(r,t){for(const[n,i]of this._pairs)t=r(t,i,n);return t}sort(r){return new Br({[Zr]:()=>{var t;return Tu(Ks(t=[...this._pairs]).call(t,(n,i)=>{let[a,o]=n,[s,u]=i;return r(o,u,a,s)}))}})}}function Tg(e,r){var t=Ya(e);if(oy){var n=oy(e);r&&(n=J(n).call(n,function(i){return ly(e,i).enumerable})),t.push.apply(t,n)}return t}function Pg(e){for(var r=1;r<arguments.length;r++){var t,n,i=arguments[r]!=null?arguments[r]:{};r%2?Fr(t=Tg(Object(i),!0)).call(t,function(a){fr(e,a,i[a])}):gy?Cq(e,gy(i)):Fr(n=Tg(Object(i))).call(n,function(a){Oy(e,a,ly(i,a))})}return e}function fO(e,r){return e[r]==null&&(e[r]=jI()),e}class wg extends Ye{get idProp(){return this._idProp}constructor(r,t){super(),fr(this,"_queue",null),r&&!dr(r)&&(t=r,r=[]),this._options=t||{},this._data=new im,this.length=0,this._idProp=this._options.fieldId||"id",r&&r.length&&this.add(r),this.setOptions(t)}setOptions(r){r&&r.queue!==void 0&&(r.queue===!1?this._queue&&(this._queue.destroy(),this._queue=null):(this._queue||(this._queue=Rt.extend(this,{replace:["add","update","remove"]})),r.queue&&typeof r.queue=="object"&&this._queue.setOptions(r.queue)))}add(r,t){const n=[];let i;if(dr(r)){const a=sr(r).call(r,o=>o[this._idProp]);if(tI(a).call(a,o=>this._data.has(o)))throw new Error("A duplicate id was found in the parameter array.");for(let o=0,s=r.length;o<s;o++)i=this._addItem(r[o]),n.push(i)}else if(r&&typeof r=="object")i=this._addItem(r),n.push(i);else throw new Error("Unknown dataType");return n.length&&this._trigger("add",{items:n},t),n}update(r,t){const n=[],i=[],a=[],o=[],s=this._idProp,u=c=>{const f=c[s];if(f!=null&&this._data.has(f)){const v=c,h=Gd({},this._data.get(f)),l=this._updateItem(v);i.push(l),o.push(v),a.push(h)}else{const v=this._addItem(c);n.push(v)}};if(dr(r))for(let c=0,f=r.length;c<f;c++)r[c]&&typeof r[c]=="object"?u(r[c]):console.warn("Ignoring input item, which is not an object at index "+c);else if(r&&typeof r=="object")u(r);else throw new Error("Unknown dataType");if(n.length&&this._trigger("add",{items:n},t),i.length){const c={items:i,oldData:a,data:o};this._trigger("update",c,t)}return JS(n).call(n,i)}updateOnly(r,t){var n;dr(r)||(r=[r]);const i=sr(n=sr(r).call(r,a=>{const o=this._data.get(a[this._idProp]);if(o==null)throw new Error("Updating non-existent items is not allowed.");return{oldData:o,update:a}})).call(n,a=>{let{oldData:o,update:s}=a;const u=o[this._idProp],c=fq(o,s);return this._data.set(u,c),{id:u,oldData:o,updatedData:c}});if(i.length){const a={items:sr(i).call(i,o=>o.id),oldData:sr(i).call(i,o=>o.oldData),data:sr(i).call(i,o=>o.updatedData)};return this._trigger("update",a,t),a.items}else return[]}get(r,t){let n,i,a;Qs(r)?(n=r,a=t):dr(r)?(i=r,a=t):a=r;const o=a&&a.returnType==="Object"?"Object":"Array",s=a&&J(a),u=[];let c,f,v;if(n!=null)c=this._data.get(n),c&&s&&!s(c)&&(c=void 0);else if(i!=null)for(let l=0,d=i.length;l<d;l++)c=this._data.get(i[l]),c!=null&&(!s||s(c))&&u.push(c);else{var h;f=[...Jr(h=this._data).call(h)];for(let l=0,d=f.length;l<d;l++)v=f[l],c=this._data.get(v),c!=null&&(!s||s(c))&&u.push(c)}if(a&&a.order&&n==null&&this._sort(u,a.order),a&&a.fields){const l=a.fields;if(n!=null&&c!=null)c=this._filterFields(c,l);else for(let d=0,p=u.length;d<p;d++)u[d]=this._filterFields(u[d],l)}if(o=="Object"){const l={};for(let d=0,p=u.length;d<p;d++){const S=u[d],g=S[this._idProp];l[g]=S}return l}else return n!=null?c??null:u}getIds(r){const t=this._data,n=r&&J(r),i=r&&r.order,a=[...Jr(t).call(t)],o=[];if(n)if(i){const s=[];for(let u=0,c=a.length;u<c;u++){const f=a[u],v=this._data.get(f);v!=null&&n(v)&&s.push(v)}this._sort(s,i);for(let u=0,c=s.length;u<c;u++)o.push(s[u][this._idProp])}else for(let s=0,u=a.length;s<u;s++){const c=a[s],f=this._data.get(c);f!=null&&n(f)&&o.push(f[this._idProp])}else if(i){const s=[];for(let u=0,c=a.length;u<c;u++){const f=a[u];s.push(t.get(f))}this._sort(s,i);for(let u=0,c=s.length;u<c;u++)o.push(s[u][this._idProp])}else for(let s=0,u=a.length;s<u;s++){const c=a[s],f=t.get(c);f!=null&&o.push(f[this._idProp])}return o}getDataSet(){return this}forEach(r,t){const n=t&&J(t),i=this._data,a=[...Jr(i).call(i)];if(t&&t.order){const o=this.get(t);for(let s=0,u=o.length;s<u;s++){const c=o[s],f=c[this._idProp];r(c,f)}}else for(let o=0,s=a.length;o<s;o++){const u=a[o],c=this._data.get(u);c!=null&&(!n||n(c))&&r(c,u)}}map(r,t){const n=t&&J(t),i=[],a=this._data,o=[...Jr(a).call(a)];for(let s=0,u=o.length;s<u;s++){const c=o[s],f=this._data.get(c);f!=null&&(!n||n(f))&&i.push(r(f,c))}return t&&t.order&&this._sort(i,t.order),i}_filterFields(r,t){var n;return r&&Eh(n=dr(t)?t:Ya(t)).call(n,(i,a)=>(i[a]=r[a],i),{})}_sort(r,t){if(typeof t=="string"){const n=t;Ks(r).call(r,(i,a)=>{const o=i[n],s=a[n];return o>s?1:o<s?-1:0})}else if(typeof t=="function")Ks(r).call(r,t);else throw new TypeError("Order must be a function or a string")}remove(r,t){const n=[],i=[],a=dr(r)?r:[r];for(let o=0,s=a.length;o<s;o++){const u=this._remove(a[o]);if(u){const c=u[this._idProp];c!=null&&(n.push(c),i.push(u))}}return n.length&&this._trigger("remove",{items:n,oldData:i},t),n}_remove(r){let t;if(Qs(r)?t=r:r&&typeof r=="object"&&(t=r[this._idProp]),t!=null&&this._data.has(t)){const n=this._data.get(t)||null;return this._data.delete(t),--this.length,n}return null}clear(r){var t;const n=[...Jr(t=this._data).call(t)],i=[];for(let a=0,o=n.length;a<o;a++)i.push(this._data.get(n[a]));return this._data.clear(),this.length=0,this._trigger("remove",{items:n,oldData:i},r),n}max(r){let t=null,n=null;for(const a of wm(i=this._data).call(i)){var i;const o=a[r];typeof o=="number"&&(n==null||o>n)&&(t=a,n=o)}return t||null}min(r){let t=null,n=null;for(const a of wm(i=this._data).call(i)){var i;const o=a[r];typeof o=="number"&&(n==null||o<n)&&(t=a,n=o)}return t||null}distinct(r){const t=this._data,n=[...Jr(t).call(t)],i=[];let a=0;for(let o=0,s=n.length;o<s;o++){const u=n[o],f=t.get(u)[r];let v=!1;for(let h=0;h<a;h++)if(i[h]==f){v=!0;break}!v&&f!==void 0&&(i[a]=f,a++)}return i}_addItem(r){const t=fO(r,this._idProp),n=t[this._idProp];if(this._data.has(n))throw new Error("Cannot add item: item with id "+n+" already exists");return this._data.set(n,t),++this.length,n}_updateItem(r){const t=r[this._idProp];if(t==null)throw new Error("Cannot update item: item has no id (item: "+lE(r)+")");const n=this._data.get(t);if(!n)throw new Error("Cannot update item: no item with id "+t+" found");return this._data.set(t,Pg(Pg({},n),r)),t}stream(r){if(r){const n=this._data;return new Br({*[Zr](){for(const i of r){const a=n.get(i);a!=null&&(yield[i,a])}}})}else{var t;return new Br({[Zr]:Ur(t=AI(this._data)).call(t,this._data)})}}}class Pu extends Ye{get idProp(){return this.getDataSet().idProp}constructor(r,t){var n;super(),fr(this,"length",0),fr(this,"_ids",new Tt),this._options=t||{},this._listener=Ur(n=this._onEvent).call(n,this),this.setData(r)}setData(r){if(this._data){this._data.off&&this._data.off("*",this._listener);const t=this._data.getIds({filter:J(this._options)}),n=this._data.get(t);this._ids.clear(),this.length=0,this._trigger("remove",{items:t,oldData:n})}if(r!=null){this._data=r;const t=this._data.getIds({filter:J(this._options)});for(let n=0,i=t.length;n<i;n++){const a=t[n];this._ids.add(a)}this.length=t.length,this._trigger("add",{items:t})}else this._data=new wg;this._data.on&&this._data.on("*",this._listener)}refresh(){const r=this._data.getIds({filter:J(this._options)}),t=[...this._ids],n={},i=[],a=[],o=[];for(let s=0,u=r.length;s<u;s++){const c=r[s];n[c]=!0,this._ids.has(c)||(i.push(c),this._ids.add(c))}for(let s=0,u=t.length;s<u;s++){const c=t[s],f=this._data.get(c);f==null?console.error("If you see this, report it please."):n[c]||(a.push(c),o.push(f),this._ids.delete(c))}this.length+=i.length-a.length,i.length&&this._trigger("add",{items:i}),a.length&&this._trigger("remove",{items:a,oldData:o})}get(r,t){if(this._data==null)return null;let n=null,i;Qs(r)||dr(r)?(n=r,i=t):i=r;const a=Gd({},this._options,i),o=J(this._options),s=i&&J(i);return o&&s&&(a.filter=u=>o(u)&&s(u)),n==null?this._data.get(a):this._data.get(n,a)}getIds(r){if(this._data.length){const t=J(this._options),n=r!=null?J(r):null;let i;return n?t?i=a=>t(a)&&n(a):i=n:i=t,this._data.getIds({filter:i,order:r&&r.order})}else return[]}forEach(r,t){if(this._data){var n;const i=J(this._options),a=t&&J(t);let o;a?i?o=function(s){return i(s)&&a(s)}:o=a:o=i,Fr(n=this._data).call(n,r,{filter:o,order:t&&t.order})}}map(r,t){if(this._data){var n;const i=J(this._options),a=t&&J(t);let o;return a?i?o=s=>i(s)&&a(s):o=a:o=i,sr(n=this._data).call(n,r,{filter:o,order:t&&t.order})}else return[]}getDataSet(){return this._data.getDataSet()}stream(r){var t;return this._data.stream(r||{[Zr]:Ur(t=Jr(this._ids)).call(t,this._ids)})}dispose(){var r;(r=this._data)!==null&&r!==void 0&&r.off&&this._data.off("*",this._listener);const t="This data view has already been disposed of.",n={get:()=>{throw new Error(t)},set:()=>{throw new Error(t)},configurable:!1};for(const i of id(Pu.prototype))Oy(this,i,n)}_onEvent(r,t,n){if(!t||!t.items||!this._data)return;const i=t.items,a=[],o=[],s=[],u=[],c=[],f=[];switch(r){case"add":for(let v=0,h=i.length;v<h;v++){const l=i[v];this.get(l)&&(this._ids.add(l),a.push(l))}break;case"update":for(let v=0,h=i.length;v<h;v++){const l=i[v];this.get(l)?this._ids.has(l)?(o.push(l),c.push(t.data[v]),u.push(t.oldData[v])):(this._ids.add(l),a.push(l)):this._ids.has(l)&&(this._ids.delete(l),s.push(l),f.push(t.oldData[v]))}break;case"remove":for(let v=0,h=i.length;v<h;v++){const l=i[v];this._ids.has(l)&&(this._ids.delete(l),s.push(l),f.push(t.oldData[v]))}break}this.length+=a.length-s.length,a.length&&this._trigger("add",{items:a},n),o.length&&this._trigger("update",{items:o,oldData:u,data:c},n),s.length&&this._trigger("remove",{items:s,oldData:f},n)}}function Ag(e,r){return typeof r=="object"&&r!==null&&e===r.idProp&&typeof r.add=="function"&&typeof r.clear=="function"&&typeof r.distinct=="function"&&typeof Fr(r)=="function"&&typeof r.get=="function"&&typeof r.getDataSet=="function"&&typeof r.getIds=="function"&&typeof r.length=="number"&&typeof sr(r)=="function"&&typeof r.max=="function"&&typeof r.min=="function"&&typeof r.off=="function"&&typeof r.on=="function"&&typeof r.remove=="function"&&typeof r.setOptions=="function"&&typeof r.stream=="function"&&typeof r.update=="function"&&typeof r.updateOnly=="function"}function vO(e,r){return typeof r=="object"&&r!==null&&e===r.idProp&&typeof Fr(r)=="function"&&typeof r.get=="function"&&typeof r.getDataSet=="function"&&typeof r.getIds=="function"&&typeof r.length=="number"&&typeof sr(r)=="function"&&typeof r.off=="function"&&typeof r.on=="function"&&typeof r.stream=="function"&&Ag(e,r.getDataSet())}}}]);

//# sourceMappingURL=vis-data.b412e34aae4ec6e73f38.js.map